/* BASICS */

.CodeMirror {
  /* Set height, width, borders, and global font properties here */
  font-family: monospace;
  height: 300px;
  color: black;
  direction: ltr;
}

/* PADDING */

.CodeMirror-lines {
  padding: 4px 0; /* Vertical padding around content */
}
.CodeMirror pre.CodeMirror-line,
.CodeMirror pre.CodeMirror-line-like {
  padding: 0 4px; /* Horizontal padding of content */
}

.CodeMirror-scrollbar-filler, .CodeMirror-gutter-filler {
  background-color: white; /* The little square between H and V scrollbars */
}

/* GUTTER */

.CodeMirror-gutters {
  border-right: 1px solid #ddd;
  background-color: #f7f7f7;
  white-space: nowrap;
}
.CodeMirror-linenumbers {}
.CodeMirror-linenumber {
  padding: 0 3px 0 5px;
  min-width: 20px;
  text-align: right;
  color: #999;
  white-space: nowrap;
}

.CodeMirror-guttermarker { color: black; }
.CodeMirror-guttermarker-subtle { color: #999; }

/* CURSOR */

.CodeMirror-cursor {
  border-left: 1px solid black;
  border-right: none;
  width: 0;
}
/* Shown when moving in bi-directional text */
.CodeMirror div.CodeMirror-secondarycursor {
  border-left: 1px solid silver;
}
.cm-fat-cursor .CodeMirror-cursor {
  width: auto;
  border: 0 !important;
  background: #7e7;
}
.cm-fat-cursor div.CodeMirror-cursors {
  z-index: 1;
}
.cm-fat-cursor .CodeMirror-line::selection,
.cm-fat-cursor .CodeMirror-line > span::selection, 
.cm-fat-cursor .CodeMirror-line > span > span::selection { background: transparent; }
.cm-fat-cursor .CodeMirror-line::-moz-selection,
.cm-fat-cursor .CodeMirror-line > span::-moz-selection,
.cm-fat-cursor .CodeMirror-line > span > span::-moz-selection { background: transparent; }
.cm-fat-cursor { caret-color: transparent; }
@keyframes blink {
  0% {}
  50% { background-color: transparent; }
  100% {}
}

/* Can style cursor different in overwrite (non-insert) mode */
.CodeMirror-overwrite .CodeMirror-cursor {}

.cm-tab { display: inline-block; text-decoration: inherit; }

.CodeMirror-rulers {
  position: absolute;
  left: 0; right: 0; top: -50px; bottom: 0;
  overflow: hidden;
}
.CodeMirror-ruler {
  border-left: 1px solid #ccc;
  top: 0; bottom: 0;
  position: absolute;
}

/* DEFAULT THEME */

.cm-s-default .cm-header {color: blue;}
.cm-s-default .cm-quote {color: #090;}
.cm-negative {color: #d44;}
.cm-positive {color: #292;}
.cm-header, .cm-strong {font-weight: bold;}
.cm-em {font-style: italic;}
.cm-link {text-decoration: underline;}
.cm-strikethrough {text-decoration: line-through;}

.cm-s-default .cm-keyword {color: #708;}
.cm-s-default .cm-atom {color: #219;}
.cm-s-default .cm-number {color: #164;}
.cm-s-default .cm-def {color: #00f;}
.cm-s-default .cm-variable,
.cm-s-default .cm-punctuation,
.cm-s-default .cm-property,
.cm-s-default .cm-operator {}
.cm-s-default .cm-variable-2 {color: #05a;}
.cm-s-default .cm-variable-3, .cm-s-default .cm-type {color: #085;}
.cm-s-default .cm-comment {color: #a50;}
.cm-s-default .cm-string {color: #a11;}
.cm-s-default .cm-string-2 {color: #f50;}
.cm-s-default .cm-meta {color: #555;}
.cm-s-default .cm-qualifier {color: #555;}
.cm-s-default .cm-builtin {color: #30a;}
.cm-s-default .cm-bracket {color: #997;}
.cm-s-default .cm-tag {color: #170;}
.cm-s-default .cm-attribute {color: #00c;}
.cm-s-default .cm-hr {color: #999;}
.cm-s-default .cm-link {color: #00c;}

.cm-s-default .cm-error {color: #f00;}
.cm-invalidchar {color: #f00;}

.CodeMirror-composing { border-bottom: 2px solid; }

/* Default styles for common addons */

div.CodeMirror span.CodeMirror-matchingbracket {color: #0b0;}
div.CodeMirror span.CodeMirror-nonmatchingbracket {color: #a22;}
.CodeMirror-matchingtag { background: rgba(255, 150, 0, .3); }
.CodeMirror-activeline-background {background: #e8f2ff;}

/* STOP */

/* The rest of this file contains styles related to the mechanics of
   the editor. You probably shouldn't touch them. */

.CodeMirror {
  position: relative;
  overflow: hidden;
  background: white;
}

.CodeMirror-scroll {
  overflow: scroll !important; /* Things will break if this is overridden */
  /* 50px is the magic margin used to hide the element's real scrollbars */
  /* See overflow: hidden in .CodeMirror */
  margin-bottom: -50px; margin-right: -50px;
  padding-bottom: 50px;
  height: 100%;
  outline: none; /* Prevent dragging from highlighting the element */
  position: relative;
  z-index: 0;
}
.CodeMirror-sizer {
  position: relative;
  border-right: 50px solid transparent;
}

/* The fake, visible scrollbars. Used to force redraw during scrolling
   before actual scrolling happens, thus preventing shaking and
   flickering artifacts. */
.CodeMirror-vscrollbar, .CodeMirror-hscrollbar, .CodeMirror-scrollbar-filler, .CodeMirror-gutter-filler {
  position: absolute;
  z-index: 6;
  display: none;
  outline: none;
}
.CodeMirror-vscrollbar {
  right: 0; top: 0;
  overflow-x: hidden;
  overflow-y: scroll;
}
.CodeMirror-hscrollbar {
  bottom: 0; left: 0;
  overflow-y: hidden;
  overflow-x: scroll;
}
.CodeMirror-scrollbar-filler {
  right: 0; bottom: 0;
}
.CodeMirror-gutter-filler {
  left: 0; bottom: 0;
}

.CodeMirror-gutters {
  position: absolute; left: 0; top: 0;
  min-height: 100%;
  z-index: 3;
}
.CodeMirror-gutter {
  white-space: normal;
  height: 100%;
  display: inline-block;
  vertical-align: top;
  margin-bottom: -50px;
}
.CodeMirror-gutter-wrapper {
  position: absolute;
  z-index: 4;
  background: none !important;
  border: none !important;
}
.CodeMirror-gutter-background {
  position: absolute;
  top: 0; bottom: 0;
  z-index: 4;
}
.CodeMirror-gutter-elt {
  position: absolute;
  cursor: default;
  z-index: 4;
}
.CodeMirror-gutter-wrapper ::selection { background-color: transparent }
.CodeMirror-gutter-wrapper ::-moz-selection { background-color: transparent }

.CodeMirror-lines {
  cursor: text;
  min-height: 1px; /* prevents collapsing before first draw */
}
.CodeMirror pre.CodeMirror-line,
.CodeMirror pre.CodeMirror-line-like {
  /* Reset some styles that the rest of the page might have set */ border-radius: 0;
  border-width: 0;
  background: transparent;
  font-family: inherit;
  font-size: inherit;
  margin: 0;
  white-space: pre;
  word-wrap: normal;
  line-height: inherit;
  color: inherit;
  z-index: 2;
  position: relative;
  overflow: visible;
  -webkit-tap-highlight-color: transparent;
  font-variant-ligatures: contextual;
}
.CodeMirror-wrap pre.CodeMirror-line,
.CodeMirror-wrap pre.CodeMirror-line-like {
  word-wrap: break-word;
  white-space: pre-wrap;
  word-break: normal;
}

.CodeMirror-linebackground {
  position: absolute;
  left: 0; right: 0; top: 0; bottom: 0;
  z-index: 0;
}

.CodeMirror-linewidget {
  position: relative;
  z-index: 2;
  padding: 0.1px; /* Force widget margins to stay inside of the container */
}

.CodeMirror-widget {}

.CodeMirror-rtl pre { direction: rtl; }

.CodeMirror-code {
  outline: none;
}

/* Force content-box sizing for the elements where we expect it */
.CodeMirror-scroll,
.CodeMirror-sizer,
.CodeMirror-gutter,
.CodeMirror-gutters,
.CodeMirror-linenumber {
  box-sizing: content-box;
}

.CodeMirror-measure {
  position: absolute;
  width: 100%;
  height: 0;
  overflow: hidden;
  visibility: hidden;
}

.CodeMirror-cursor {
  position: absolute;
  pointer-events: none;
}
.CodeMirror-measure pre { position: static; }

div.CodeMirror-cursors {
  visibility: hidden;
  position: relative;
  z-index: 3;
}
div.CodeMirror-dragcursors {
  visibility: visible;
}

.CodeMirror-focused div.CodeMirror-cursors {
  visibility: visible;
}

.CodeMirror-selected { background: #d9d9d9; }
.CodeMirror-focused .CodeMirror-selected { background: #d7d4f0; }
.CodeMirror-crosshair { cursor: crosshair; }
.CodeMirror-line::selection, .CodeMirror-line > span::selection, .CodeMirror-line > span > span::selection { background: #d7d4f0; }
.CodeMirror-line::-moz-selection, .CodeMirror-line > span::-moz-selection, .CodeMirror-line > span > span::-moz-selection { background: #d7d4f0; }

.cm-searching {
  background-color: #ffa;
  background-color: rgba(255, 255, 0, .4);
}

/* Used to force a border model for a node */
.cm-force-border { padding-right: .1px; }

@media print {
  /* Hide the cursor when printing */
  .CodeMirror div.CodeMirror-cursors {
    visibility: hidden;
  }
}

/* See issue #2901 */
.cm-tab-wrap-hack:after { content: ''; }

/* Help users use markselection to safely style text background */
span.CodeMirror-selectedtext { background: none; }

/* The lint marker gutter */
.CodeMirror-lint-markers {
  width: 16px;
}

.CodeMirror-lint-tooltip {
  background-color: #ffd;
  border: 1px solid black;
  border-radius: 4px 4px 4px 4px;
  color: black;
  font-family: monospace;
  font-size: 10pt;
  overflow: hidden;
  padding: 2px 5px;
  position: fixed;
  white-space: pre;
  white-space: pre-wrap;
  z-index: 100;
  max-width: 600px;
  opacity: 0;
  transition: opacity .4s;
  -moz-transition: opacity .4s;
  -webkit-transition: opacity .4s;
  -o-transition: opacity .4s;
  -ms-transition: opacity .4s;
}

.CodeMirror-lint-mark {
  background-position: left bottom;
  background-repeat: repeat-x;
}

.CodeMirror-lint-mark-warning {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAADCAYAAAC09K7GAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9sJFhQXEbhTg7YAAAAZdEVYdENvbW1lbnQAQ3JlYXRlZCB3aXRoIEdJTVBXgQ4XAAAAMklEQVQI12NkgIIvJ3QXMjAwdDN+OaEbysDA4MPAwNDNwMCwiOHLCd1zX07o6kBVGQEAKBANtobskNMAAAAASUVORK5CYII=");
}

.CodeMirror-lint-mark-error {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAADCAYAAAC09K7GAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9sJDw4cOCW1/KIAAAAZdEVYdENvbW1lbnQAQ3JlYXRlZCB3aXRoIEdJTVBXgQ4XAAAAHElEQVQI12NggIL/DAz/GdA5/xkY/qPKMDAwAADLZwf5rvm+LQAAAABJRU5ErkJggg==");
}

.CodeMirror-lint-marker {
  background-position: center center;
  background-repeat: no-repeat;
  cursor: pointer;
  display: inline-block;
  height: 16px;
  width: 16px;
  vertical-align: middle;
  position: relative;
}

.CodeMirror-lint-message {
  padding-left: 18px;
  background-position: top left;
  background-repeat: no-repeat;
}

.CodeMirror-lint-marker-warning, .CodeMirror-lint-message-warning {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAMAAAAoLQ9TAAAANlBMVEX/uwDvrwD/uwD/uwD/uwD/uwD/uwD/uwD/uwD6twD/uwAAAADurwD2tQD7uAD+ugAAAAD/uwDhmeTRAAAADHRSTlMJ8mN1EYcbmiixgACm7WbuAAAAVklEQVR42n3PUQqAIBBFUU1LLc3u/jdbOJoW1P08DA9Gba8+YWJ6gNJoNYIBzAA2chBth5kLmG9YUoG0NHAUwFXwO9LuBQL1giCQb8gC9Oro2vp5rncCIY8L8uEx5ZkAAAAASUVORK5CYII=");
}

.CodeMirror-lint-marker-error, .CodeMirror-lint-message-error {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAMAAAAoLQ9TAAAAHlBMVEW7AAC7AACxAAC7AAC7AAAAAAC4AAC5AAD///+7AAAUdclpAAAABnRSTlMXnORSiwCK0ZKSAAAATUlEQVR42mWPOQ7AQAgDuQLx/z8csYRmPRIFIwRGnosRrpamvkKi0FTIiMASR3hhKW+hAN6/tIWhu9PDWiTGNEkTtIOucA5Oyr9ckPgAWm0GPBog6v4AAAAASUVORK5CYII=");
}

.CodeMirror-lint-marker-multiple {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAcAAAAHCAMAAADzjKfhAAAACVBMVEUAAAAAAAC/v7914kyHAAAAAXRSTlMAQObYZgAAACNJREFUeNo1ioEJAAAIwmz/H90iFFSGJgFMe3gaLZ0od+9/AQZ0ADosbYraAAAAAElFTkSuQmCC");
  background-repeat: no-repeat;
  background-position: right bottom;
  width: 100%; height: 100%;
}

.CodeMirror-lint-line-error {
  background-color: rgba(183, 76, 81, 0.08);
}

.CodeMirror-lint-line-warning {
  background-color: rgba(255, 211, 0, 0.1);
}

/*! jQuery UI - v1.14.2 - 2026-01-28
* https://jqueryui.com
* Includes: core.css, accordion.css, autocomplete.css, menu.css, button.css, controlgroup.css, checkboxradio.css, datepicker.css, dialog.css, draggable.css, resizable.css, progressbar.css, selectable.css, selectmenu.css, slider.css, sortable.css, spinner.css, tabs.css, tooltip.css, theme.css
* To view and modify this theme, visit https://jqueryui.com/themeroller/?ffDefault=Arial%2CHelvetica%2Csans-serif&fsDefault=1em&fwDefault=normal&cornerRadius=3px&bgColorHeader=e9e9e9&bgTextureHeader=flat&borderColorHeader=dddddd&fcHeader=333333&iconColorHeader=444444&bgColorContent=ffffff&bgTextureContent=flat&borderColorContent=dddddd&fcContent=333333&iconColorContent=444444&bgColorDefault=f6f6f6&bgTextureDefault=flat&borderColorDefault=c5c5c5&fcDefault=454545&iconColorDefault=777777&bgColorHover=ededed&bgTextureHover=flat&borderColorHover=cccccc&fcHover=2b2b2b&iconColorHover=555555&bgColorActive=007fff&bgTextureActive=flat&borderColorActive=003eff&fcActive=ffffff&iconColorActive=ffffff&bgColorHighlight=fffa90&bgTextureHighlight=flat&borderColorHighlight=dad55e&fcHighlight=777620&iconColorHighlight=777620&bgColorError=fddfdf&bgTextureError=flat&borderColorError=f1a899&fcError=5f3f3f&iconColorError=cc0000&bgColorOverlay=aaaaaa&bgTextureOverlay=flat&bgImgOpacityOverlay=0&opacityOverlay=30&bgColorShadow=666666&bgTextureShadow=flat&bgImgOpacityShadow=0&opacityShadow=30&thicknessShadow=5px&offsetTopShadow=0px&offsetLeftShadow=0px&cornerRadiusShadow=8px
* Copyright OpenJS Foundation and other contributors; Licensed MIT */

/* Layout helpers
----------------------------------*/
.ui-helper-hidden {
	display: none;
}
.ui-helper-hidden-accessible {
	border: 0;
	clip: rect(0 0 0 0);
	height: 1px;
	margin: -1px;
	overflow: hidden;
	padding: 0;
	position: absolute;
	width: 1px;
}
.ui-helper-reset {
	margin: 0;
	padding: 0;
	border: 0;
	outline: 0;
	line-height: 1.3;
	text-decoration: none;
	font-size: 100%;
	list-style: none;
}
.ui-helper-clearfix:before,
.ui-helper-clearfix:after {
	content: "";
	display: table;
	border-collapse: collapse;
}
.ui-helper-clearfix:after {
	clear: both;
}
.ui-helper-zfix {
	width: 100%;
	height: 100%;
	top: 0;
	left: 0;
	position: absolute;
	opacity: 0;
}

.ui-front {
	z-index: 100;
}


/* Interaction Cues
----------------------------------*/
.ui-state-disabled {
	cursor: default !important;
	pointer-events: none;
}


/* Icons
----------------------------------*/
.ui-icon {
	display: inline-block;
	vertical-align: middle;
	margin-top: -.25em;
	position: relative;
	text-indent: -99999px;
	overflow: hidden;
	background-repeat: no-repeat;
}

.ui-widget-icon-block {
	left: 50%;
	margin-left: -8px;
	display: block;
}

/* Misc visuals
----------------------------------*/

/* Overlays */
.ui-widget-overlay {
	position: fixed;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
}
.ui-accordion .ui-accordion-header {
	display: block;
	cursor: pointer;
	position: relative;
	margin: 2px 0 0 0;
	padding: .5em .5em .5em .7em;
	font-size: 100%;
}
.ui-accordion .ui-accordion-content {
	padding: 1em 2.2em;
	border-top: 0;
	overflow: auto;
}
.ui-autocomplete {
	position: absolute;
	top: 0;
	left: 0;
	cursor: default;
}
.ui-menu {
	list-style: none;
	padding: 0;
	margin: 0;
	display: block;
	outline: 0;
}
.ui-menu .ui-menu {
	position: absolute;
}
.ui-menu .ui-menu-item {
	margin: 0;
	cursor: pointer;
}
.ui-menu .ui-menu-item-wrapper {
	position: relative;
	padding: 3px 1em 3px .4em;
}
.ui-menu .ui-menu-divider {
	margin: 5px 0;
	height: 0;
	font-size: 0;
	line-height: 0;
	border-width: 1px 0 0 0;
}
.ui-menu .ui-state-focus,
.ui-menu .ui-state-active {
	margin: -1px;
}

/* icon support */
.ui-menu-icons {
	position: relative;
}
.ui-menu-icons .ui-menu-item-wrapper {
	padding-left: 2em;
}

/* left-aligned */
.ui-menu .ui-icon {
	position: absolute;
	top: 0;
	bottom: 0;
	left: .2em;
	margin: auto 0;
}

/* right-aligned */
.ui-menu .ui-menu-icon {
	left: auto;
	right: 0;
}
.ui-button {
	padding: .4em 1em;
	display: inline-block;
	position: relative;
	line-height: normal;
	margin-right: .1em;
	cursor: pointer;
	vertical-align: middle;
	text-align: center;
	-webkit-user-select: none;
	user-select: none;
}

.ui-button,
.ui-button:link,
.ui-button:visited,
.ui-button:hover,
.ui-button:active {
	text-decoration: none;
}

/* to make room for the icon, a width needs to be set here */
.ui-button-icon-only {
	width: 2em;
	box-sizing: border-box;
	text-indent: -9999px;
	white-space: nowrap;
}

/* no icon support for input elements */
input.ui-button.ui-button-icon-only {
	text-indent: 0;
}

/* button icon element(s) */
.ui-button-icon-only .ui-icon {
	position: absolute;
	top: 50%;
	left: 50%;
	margin-top: -8px;
	margin-left: -8px;
}

.ui-button.ui-icon-notext .ui-icon {
	padding: 0;
	width: 2.1em;
	height: 2.1em;
	text-indent: -9999px;
	white-space: nowrap;

}

input.ui-button.ui-icon-notext .ui-icon {
	width: auto;
	height: auto;
	text-indent: 0;
	white-space: normal;
	padding: .4em 1em;
}

/* workarounds */
/* Support: Firefox 5 - 125+ */
input.ui-button::-moz-focus-inner,
button.ui-button::-moz-focus-inner {
	border: 0;
	padding: 0;
}
.ui-controlgroup {
	vertical-align: middle;
	display: inline-block;
}
.ui-controlgroup > .ui-controlgroup-item {
	float: left;
	margin-left: 0;
	margin-right: 0;
}
.ui-controlgroup > .ui-controlgroup-item:focus,
.ui-controlgroup > .ui-controlgroup-item.ui-visual-focus {
	z-index: 9999;
}
.ui-controlgroup-vertical > .ui-controlgroup-item {
	display: block;
	float: none;
	width: 100%;
	margin-top: 0;
	margin-bottom: 0;
	text-align: left;
}
.ui-controlgroup-vertical .ui-controlgroup-item {
	box-sizing: border-box;
}
.ui-controlgroup .ui-controlgroup-label {
	padding: .4em 1em;
}
.ui-controlgroup .ui-controlgroup-label span {
	font-size: 80%;
}
.ui-controlgroup-horizontal .ui-controlgroup-label + .ui-controlgroup-item {
	border-left: none;
}
.ui-controlgroup-vertical .ui-controlgroup-label + .ui-controlgroup-item {
	border-top: none;
}
.ui-controlgroup-horizontal .ui-controlgroup-label.ui-widget-content {
	border-right: none;
}
.ui-controlgroup-vertical .ui-controlgroup-label.ui-widget-content {
	border-bottom: none;
}

/* Spinner specific style fixes */
.ui-controlgroup-vertical .ui-spinner-input {
	width: calc( 100% - 2.4em );
}
.ui-controlgroup-vertical .ui-spinner .ui-spinner-up {
	border-top-style: solid;
}

.ui-checkboxradio-label .ui-icon-background {
	box-shadow: inset 1px 1px 1px #ccc;
	border-radius: .12em;
	border: none;
}
.ui-checkboxradio-radio-label .ui-icon-background {
	width: 16px;
	height: 16px;
	border-radius: 1em;
	overflow: visible;
	border: none;
}
.ui-checkboxradio-radio-label.ui-checkboxradio-checked .ui-icon,
.ui-checkboxradio-radio-label.ui-checkboxradio-checked:hover .ui-icon {
	background-image: none;
	width: 8px;
	height: 8px;
	border-width: 4px;
	border-style: solid;
}
.ui-checkboxradio-disabled {
	pointer-events: none;
}
.ui-datepicker {
	width: 17em;
	padding: .2em .2em 0;
	display: none;
}
.ui-datepicker .ui-datepicker-header {
	position: relative;
	padding: .2em 0;
}
.ui-datepicker .ui-datepicker-prev,
.ui-datepicker .ui-datepicker-next {
	position: absolute;
	top: 2px;
	width: 1.8em;
	height: 1.8em;
}
.ui-datepicker .ui-datepicker-prev-hover,
.ui-datepicker .ui-datepicker-next-hover {
	top: 1px;
}
.ui-datepicker .ui-datepicker-prev {
	left: 2px;
}
.ui-datepicker .ui-datepicker-next {
	right: 2px;
}
.ui-datepicker .ui-datepicker-prev-hover {
	left: 1px;
}
.ui-datepicker .ui-datepicker-next-hover {
	right: 1px;
}
.ui-datepicker .ui-datepicker-prev span,
.ui-datepicker .ui-datepicker-next span {
	display: block;
	position: absolute;
	left: 50%;
	margin-left: -8px;
	top: 50%;
	margin-top: -8px;
}
.ui-datepicker .ui-datepicker-title {
	margin: 0 2.3em;
	line-height: 1.8em;
	text-align: center;
}
.ui-datepicker .ui-datepicker-title select {
	font-size: 1em;
	margin: 1px 0;
}
.ui-datepicker select.ui-datepicker-month,
.ui-datepicker select.ui-datepicker-year {
	width: 45%;
}
.ui-datepicker table {
	width: 100%;
	font-size: .9em;
	border-collapse: collapse;
	margin: 0 0 .4em;
}
.ui-datepicker th {
	padding: .7em .3em;
	text-align: center;
	font-weight: bold;
	border: 0;
}
.ui-datepicker td {
	border: 0;
	padding: 1px;
}
.ui-datepicker td span,
.ui-datepicker td a {
	display: block;
	padding: .2em;
	text-align: right;
	text-decoration: none;
}
.ui-datepicker .ui-datepicker-buttonpane {
	background-image: none;
	margin: .7em 0 0 0;
	padding: 0 .2em;
	border-left: 0;
	border-right: 0;
	border-bottom: 0;
}
.ui-datepicker .ui-datepicker-buttonpane button {
	float: right;
	margin: .5em .2em .4em;
	cursor: pointer;
	padding: .2em .6em .3em .6em;
	width: auto;
	overflow: visible;
}
.ui-datepicker .ui-datepicker-buttonpane button.ui-datepicker-current {
	float: left;
}

/* with multiple calendars */
.ui-datepicker.ui-datepicker-multi {
	width: auto;
}
.ui-datepicker-multi .ui-datepicker-group {
	float: left;
}
.ui-datepicker-multi .ui-datepicker-group table {
	width: 95%;
	margin: 0 auto .4em;
}
.ui-datepicker-multi-2 .ui-datepicker-group {
	width: 50%;
}
.ui-datepicker-multi-3 .ui-datepicker-group {
	width: 33.3%;
}
.ui-datepicker-multi-4 .ui-datepicker-group {
	width: 25%;
}
.ui-datepicker-multi .ui-datepicker-group-last .ui-datepicker-header,
.ui-datepicker-multi .ui-datepicker-group-middle .ui-datepicker-header {
	border-left-width: 0;
}
.ui-datepicker-multi .ui-datepicker-buttonpane {
	clear: left;
}
.ui-datepicker-row-break {
	clear: both;
	width: 100%;
	font-size: 0;
}

/* RTL support */
.ui-datepicker-rtl {
	direction: rtl;
}
.ui-datepicker-rtl .ui-datepicker-prev {
	right: 2px;
	left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next {
	left: 2px;
	right: auto;
}
.ui-datepicker-rtl .ui-datepicker-prev:hover {
	right: 1px;
	left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next:hover {
	left: 1px;
	right: auto;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane {
	clear: right;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane button {
	float: left;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane button.ui-datepicker-current,
.ui-datepicker-rtl .ui-datepicker-group {
	float: right;
}
.ui-datepicker-rtl .ui-datepicker-group-last .ui-datepicker-header,
.ui-datepicker-rtl .ui-datepicker-group-middle .ui-datepicker-header {
	border-right-width: 0;
	border-left-width: 1px;
}

/* Icons */
.ui-datepicker .ui-icon {
	display: block;
	text-indent: -99999px;
	overflow: hidden;
	background-repeat: no-repeat;
	left: .5em;
	top: .3em;
}
.ui-dialog {
	position: absolute;
	top: 0;
	left: 0;
	padding: .2em;
	outline: 0;
}
.ui-dialog .ui-dialog-titlebar {
	padding: .4em 1em;
	position: relative;
}
.ui-dialog .ui-dialog-title {
	float: left;
	margin: .1em 0;
	white-space: nowrap;
	width: 90%;
	overflow: hidden;
	text-overflow: ellipsis;
}
.ui-dialog .ui-dialog-titlebar-close {
	position: absolute;
	right: .3em;
	top: 50%;
	width: 20px;
	margin: -10px 0 0 0;
	padding: 1px;
	height: 20px;
}
.ui-dialog .ui-dialog-content {
	position: relative;
	border: 0;
	padding: .5em 1em;
	background: none;
	overflow: auto;
}
.ui-dialog .ui-dialog-buttonpane {
	text-align: left;
	border-width: 1px 0 0 0;
	background-image: none;
	margin-top: .5em;
	padding: .3em 1em .5em .4em;
}
.ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
	float: right;
}
.ui-dialog .ui-dialog-buttonpane button {
	margin: .5em .4em .5em 0;
	cursor: pointer;
}
.ui-dialog .ui-resizable-n {
	height: 2px;
	top: 0;
}
.ui-dialog .ui-resizable-e {
	width: 2px;
	right: 0;
}
.ui-dialog .ui-resizable-s {
	height: 2px;
	bottom: 0;
}
.ui-dialog .ui-resizable-w {
	width: 2px;
	left: 0;
}
.ui-dialog .ui-resizable-se,
.ui-dialog .ui-resizable-sw,
.ui-dialog .ui-resizable-ne,
.ui-dialog .ui-resizable-nw {
	width: 7px;
	height: 7px;
}
.ui-dialog .ui-resizable-se {
	right: 0;
	bottom: 0;
}
.ui-dialog .ui-resizable-sw {
	left: 0;
	bottom: 0;
}
.ui-dialog .ui-resizable-ne {
	right: 0;
	top: 0;
}
.ui-dialog .ui-resizable-nw {
	left: 0;
	top: 0;
}
.ui-draggable .ui-dialog-titlebar {
	cursor: move;
}
.ui-draggable-handle {
	touch-action: none;
}
.ui-resizable {
	position: relative;
}
.ui-resizable-handle {
	position: absolute;
	font-size: 0.1px;
	display: block;
	touch-action: none;
}
.ui-resizable-disabled .ui-resizable-handle,
.ui-resizable-autohide .ui-resizable-handle {
	display: none;
}
.ui-resizable-n {
	cursor: n-resize;
	height: 7px;
	width: 100%;
	top: -5px;
	left: 0;
}
.ui-resizable-s {
	cursor: s-resize;
	height: 7px;
	width: 100%;
	bottom: -5px;
	left: 0;
}
.ui-resizable-e {
	cursor: e-resize;
	width: 7px;
	right: -5px;
	top: 0;
	height: 100%;
}
.ui-resizable-w {
	cursor: w-resize;
	width: 7px;
	left: -5px;
	top: 0;
	height: 100%;
}
.ui-resizable-se {
	cursor: se-resize;
	width: 12px;
	height: 12px;
	right: 1px;
	bottom: 1px;
}
.ui-resizable-sw {
	cursor: sw-resize;
	width: 9px;
	height: 9px;
	left: -5px;
	bottom: -5px;
}
.ui-resizable-nw {
	cursor: nw-resize;
	width: 9px;
	height: 9px;
	left: -5px;
	top: -5px;
}
.ui-resizable-ne {
	cursor: ne-resize;
	width: 9px;
	height: 9px;
	right: -5px;
	top: -5px;
}
.ui-progressbar {
	height: 2em;
	text-align: left;
	overflow: hidden;
}
.ui-progressbar .ui-progressbar-value {
	margin: -1px;
	height: 100%;
}
.ui-progressbar .ui-progressbar-overlay {
	background: url("data:image/gif;base64,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");
	height: 100%;
	opacity: 0.25;
}
.ui-progressbar-indeterminate .ui-progressbar-value {
	background-image: none;
}
.ui-selectable {
	touch-action: none;
}
.ui-selectable-helper {
	position: absolute;
	z-index: 100;
	border: 1px dotted black;
}
.ui-selectmenu-menu {
	padding: 0;
	margin: 0;
	position: absolute;
	top: 0;
	left: 0;
	display: none;
}
.ui-selectmenu-menu .ui-menu {
	overflow: auto;
	overflow-x: hidden;
	padding-bottom: 1px;
}
.ui-selectmenu-menu .ui-menu .ui-selectmenu-optgroup {
	font-size: 1em;
	font-weight: bold;
	line-height: 1.5;
	padding: 2px 0.4em;
	margin: 0.5em 0 0 0;
	height: auto;
	border: 0;
}
.ui-selectmenu-open {
	display: block;
}
.ui-selectmenu-text {
	display: block;
	margin-right: 20px;
	overflow: hidden;
	text-overflow: ellipsis;
}
.ui-selectmenu-button.ui-button {
	text-align: left;
	white-space: nowrap;
	width: 14em;
}
.ui-selectmenu-icon.ui-icon {
	float: right;
	margin-top: 0;
}
.ui-slider {
	position: relative;
	text-align: left;
}
.ui-slider .ui-slider-handle {
	position: absolute;
	z-index: 2;
	width: 1.2em;
	height: 1.2em;
	cursor: pointer;
	touch-action: none;
}
.ui-slider .ui-slider-range {
	position: absolute;
	z-index: 1;
	font-size: .7em;
	display: block;
	border: 0;
	background-position: 0 0;
}

.ui-slider-horizontal {
	height: .8em;
}
.ui-slider-horizontal .ui-slider-handle {
	top: -.3em;
	margin-left: -.6em;
}
.ui-slider-horizontal .ui-slider-range {
	top: 0;
	height: 100%;
}
.ui-slider-horizontal .ui-slider-range-min {
	left: 0;
}
.ui-slider-horizontal .ui-slider-range-max {
	right: 0;
}

.ui-slider-vertical {
	width: .8em;
	height: 100px;
}
.ui-slider-vertical .ui-slider-handle {
	left: -.3em;
	margin-left: 0;
	margin-bottom: -.6em;
}
.ui-slider-vertical .ui-slider-range {
	left: 0;
	width: 100%;
}
.ui-slider-vertical .ui-slider-range-min {
	bottom: 0;
}
.ui-slider-vertical .ui-slider-range-max {
	top: 0;
}
.ui-sortable-handle {
	touch-action: none;
}
.ui-spinner {
	position: relative;
	display: inline-block;
	overflow: hidden;
	padding: 0;
	vertical-align: middle;
}
.ui-spinner-input {
	border: none;
	background: none;
	color: inherit;
	padding: .222em 0;
	margin: .2em 0;
	vertical-align: middle;
	margin-left: .4em;
	margin-right: 2em;
}
.ui-spinner-button {
	width: 1.6em;
	height: 50%;
	font-size: .5em;
	padding: 0;
	margin: 0;
	text-align: center;
	position: absolute;
	cursor: default;
	display: block;
	overflow: hidden;
	right: 0;
}
/* more specificity required here to override default borders */
.ui-spinner a.ui-spinner-button {
	border-top-style: none;
	border-bottom-style: none;
	border-right-style: none;
}
.ui-spinner-up {
	top: 0;
}
.ui-spinner-down {
	bottom: 0;
}
.ui-tabs {
	position: relative;/* position: relative prevents IE scroll bug (element with position: relative inside container with overflow: auto appear as "fixed") */
	padding: .2em;
}
.ui-tabs .ui-tabs-nav {
	margin: 0;
	padding: .2em .2em 0;
}
.ui-tabs .ui-tabs-nav li {
	list-style: none;
	float: left;
	position: relative;
	top: 0;
	margin: 1px .2em 0 0;
	border-bottom-width: 0;
	padding: 0;
	white-space: nowrap;
}
.ui-tabs .ui-tabs-nav .ui-tabs-anchor {
	float: left;
	padding: .5em 1em;
	text-decoration: none;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active {
	margin-bottom: -1px;
	padding-bottom: 1px;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active .ui-tabs-anchor,
.ui-tabs .ui-tabs-nav li.ui-state-disabled .ui-tabs-anchor,
.ui-tabs .ui-tabs-nav li.ui-tabs-loading .ui-tabs-anchor {
	cursor: text;
}
.ui-tabs-collapsible .ui-tabs-nav li.ui-tabs-active .ui-tabs-anchor {
	cursor: pointer;
}
.ui-tabs .ui-tabs-panel {
	display: block;
	border-width: 0;
	padding: 1em 1.4em;
	background: none;
}
.ui-tooltip {
	padding: 8px;
	position: absolute;
	z-index: 9999;
	max-width: 300px;
}
body .ui-tooltip {
	border-width: 2px;
}
/* Component containers
----------------------------------*/
.ui-widget {
	font-family: Arial,Helvetica,sans-serif;
	font-size: 1em;
}
.ui-widget .ui-widget {
	font-size: 1em;
}
.ui-widget input,
.ui-widget select,
.ui-widget textarea,
.ui-widget button {
	font-family: Arial,Helvetica,sans-serif;
	font-size: 1em;
}
.ui-widget.ui-widget-content {
	border: 1px solid #c5c5c5;
}
.ui-widget-content {
	border: 1px solid #dddddd;
	background: #ffffff;
	color: #333333;
}
.ui-widget-content a {
	color: #333333;
}
.ui-widget-header {
	border: 1px solid #dddddd;
	background: #e9e9e9;
	color: #333333;
	font-weight: bold;
}
.ui-widget-header a {
	color: #333333;
}

/* Interaction states
----------------------------------*/
.ui-state-default,
.ui-widget-content .ui-state-default,
.ui-widget-header .ui-state-default,
.ui-button,

/* We use html here because we need a greater specificity to make sure disabled
works properly when clicked or hovered */
html .ui-button.ui-state-disabled:hover,
html .ui-button.ui-state-disabled:active {
	border: 1px solid #c5c5c5;
	background: #f6f6f6;
	font-weight: normal;
	color: #454545;
}
.ui-state-default a,
.ui-state-default a:link,
.ui-state-default a:visited,
a.ui-button,
a:link.ui-button,
a:visited.ui-button,
.ui-button {
	color: #454545;
	text-decoration: none;
}
.ui-state-hover,
.ui-widget-content .ui-state-hover,
.ui-widget-header .ui-state-hover,
.ui-state-focus,
.ui-widget-content .ui-state-focus,
.ui-widget-header .ui-state-focus,
.ui-button:hover,
.ui-button:focus {
	border: 1px solid #cccccc;
	background: #ededed;
	font-weight: normal;
	color: #2b2b2b;
}
.ui-state-hover a,
.ui-state-hover a:hover,
.ui-state-hover a:link,
.ui-state-hover a:visited,
.ui-state-focus a,
.ui-state-focus a:hover,
.ui-state-focus a:link,
.ui-state-focus a:visited,
a.ui-button:hover,
a.ui-button:focus {
	color: #2b2b2b;
	text-decoration: none;
}

.ui-visual-focus {
	box-shadow: 0 0 3px 1px rgb(94, 158, 214);
}
.ui-state-active,
.ui-widget-content .ui-state-active,
.ui-widget-header .ui-state-active,
a.ui-button:active,
.ui-button:active,
.ui-button.ui-state-active:hover {
	border: 1px solid #003eff;
	background: #007fff;
	font-weight: normal;
	color: #ffffff;
}
.ui-icon-background,
.ui-state-active .ui-icon-background {
	border: #003eff;
	background-color: #ffffff;
}
.ui-state-active a,
.ui-state-active a:link,
.ui-state-active a:visited {
	color: #ffffff;
	text-decoration: none;
}

/* Interaction Cues
----------------------------------*/
.ui-state-highlight,
.ui-widget-content .ui-state-highlight,
.ui-widget-header .ui-state-highlight {
	border: 1px solid #dad55e;
	background: #fffa90;
	color: #777620;
}
.ui-state-checked {
	border: 1px solid #dad55e;
	background: #fffa90;
}
.ui-state-highlight a,
.ui-widget-content .ui-state-highlight a,
.ui-widget-header .ui-state-highlight a {
	color: #777620;
}
.ui-state-error,
.ui-widget-content .ui-state-error,
.ui-widget-header .ui-state-error {
	border: 1px solid #f1a899;
	background: #fddfdf;
	color: #5f3f3f;
}
.ui-state-error a,
.ui-widget-content .ui-state-error a,
.ui-widget-header .ui-state-error a {
	color: #5f3f3f;
}
.ui-state-error-text,
.ui-widget-content .ui-state-error-text,
.ui-widget-header .ui-state-error-text {
	color: #5f3f3f;
}
.ui-priority-primary,
.ui-widget-content .ui-priority-primary,
.ui-widget-header .ui-priority-primary {
	font-weight: bold;
}
.ui-priority-secondary,
.ui-widget-content .ui-priority-secondary,
.ui-widget-header .ui-priority-secondary {
	opacity: .7;
	font-weight: normal;
}
.ui-state-disabled,
.ui-widget-content .ui-state-disabled,
.ui-widget-header .ui-state-disabled {
	opacity: .35;
	background-image: none;
}

/* Icons
----------------------------------*/

/* states and images */
.ui-icon {
	width: 16px;
	height: 16px;
}
.ui-icon,
.ui-widget-content .ui-icon {
	background-image: url("images/ui-icons_444444_256x240.png");
}
.ui-widget-header .ui-icon {
	background-image: url("images/ui-icons_444444_256x240.png");
}
.ui-state-hover .ui-icon,
.ui-state-focus .ui-icon,
.ui-button:hover .ui-icon,
.ui-button:focus .ui-icon {
	background-image: url("images/ui-icons_555555_256x240.png");
}
.ui-state-active .ui-icon,
.ui-button:active .ui-icon {
	background-image: url("images/ui-icons_ffffff_256x240.png");
}
.ui-state-highlight .ui-icon,
.ui-button .ui-state-highlight.ui-icon {
	background-image: url("images/ui-icons_777620_256x240.png");
}
.ui-state-error .ui-icon,
.ui-state-error-text .ui-icon {
	background-image: url("images/ui-icons_cc0000_256x240.png");
}
.ui-button .ui-icon {
	background-image: url("images/ui-icons_777777_256x240.png");
}

/* positioning */
/* Three classes needed to override `.ui-button:hover .ui-icon` */
.ui-icon-blank.ui-icon-blank.ui-icon-blank {
	background-image: none;
}
.ui-icon-caret-1-n { background-position: 0 0; }
.ui-icon-caret-1-ne { background-position: -16px 0; }
.ui-icon-caret-1-e { background-position: -32px 0; }
.ui-icon-caret-1-se { background-position: -48px 0; }
.ui-icon-caret-1-s { background-position: -65px 0; }
.ui-icon-caret-1-sw { background-position: -80px 0; }
.ui-icon-caret-1-w { background-position: -96px 0; }
.ui-icon-caret-1-nw { background-position: -112px 0; }
.ui-icon-caret-2-n-s { background-position: -128px 0; }
.ui-icon-caret-2-e-w { background-position: -144px 0; }
.ui-icon-triangle-1-n { background-position: 0 -16px; }
.ui-icon-triangle-1-ne { background-position: -16px -16px; }
.ui-icon-triangle-1-e { background-position: -32px -16px; }
.ui-icon-triangle-1-se { background-position: -48px -16px; }
.ui-icon-triangle-1-s { background-position: -65px -16px; }
.ui-icon-triangle-1-sw { background-position: -80px -16px; }
.ui-icon-triangle-1-w { background-position: -96px -16px; }
.ui-icon-triangle-1-nw { background-position: -112px -16px; }
.ui-icon-triangle-2-n-s { background-position: -128px -16px; }
.ui-icon-triangle-2-e-w { background-position: -144px -16px; }
.ui-icon-arrow-1-n { background-position: 0 -32px; }
.ui-icon-arrow-1-ne { background-position: -16px -32px; }
.ui-icon-arrow-1-e { background-position: -32px -32px; }
.ui-icon-arrow-1-se { background-position: -48px -32px; }
.ui-icon-arrow-1-s { background-position: -65px -32px; }
.ui-icon-arrow-1-sw { background-position: -80px -32px; }
.ui-icon-arrow-1-w { background-position: -96px -32px; }
.ui-icon-arrow-1-nw { background-position: -112px -32px; }
.ui-icon-arrow-2-n-s { background-position: -128px -32px; }
.ui-icon-arrow-2-ne-sw { background-position: -144px -32px; }
.ui-icon-arrow-2-e-w { background-position: -160px -32px; }
.ui-icon-arrow-2-se-nw { background-position: -176px -32px; }
.ui-icon-arrowstop-1-n { background-position: -192px -32px; }
.ui-icon-arrowstop-1-e { background-position: -208px -32px; }
.ui-icon-arrowstop-1-s { background-position: -224px -32px; }
.ui-icon-arrowstop-1-w { background-position: -240px -32px; }
.ui-icon-arrowthick-1-n { background-position: 1px -48px; }
.ui-icon-arrowthick-1-ne { background-position: -16px -48px; }
.ui-icon-arrowthick-1-e { background-position: -32px -48px; }
.ui-icon-arrowthick-1-se { background-position: -48px -48px; }
.ui-icon-arrowthick-1-s { background-position: -64px -48px; }
.ui-icon-arrowthick-1-sw { background-position: -80px -48px; }
.ui-icon-arrowthick-1-w { background-position: -96px -48px; }
.ui-icon-arrowthick-1-nw { background-position: -112px -48px; }
.ui-icon-arrowthick-2-n-s { background-position: -128px -48px; }
.ui-icon-arrowthick-2-ne-sw { background-position: -144px -48px; }
.ui-icon-arrowthick-2-e-w { background-position: -160px -48px; }
.ui-icon-arrowthick-2-se-nw { background-position: -176px -48px; }
.ui-icon-arrowthickstop-1-n { background-position: -192px -48px; }
.ui-icon-arrowthickstop-1-e { background-position: -208px -48px; }
.ui-icon-arrowthickstop-1-s { background-position: -224px -48px; }
.ui-icon-arrowthickstop-1-w { background-position: -240px -48px; }
.ui-icon-arrowreturnthick-1-w { background-position: 0 -64px; }
.ui-icon-arrowreturnthick-1-n { background-position: -16px -64px; }
.ui-icon-arrowreturnthick-1-e { background-position: -32px -64px; }
.ui-icon-arrowreturnthick-1-s { background-position: -48px -64px; }
.ui-icon-arrowreturn-1-w { background-position: -64px -64px; }
.ui-icon-arrowreturn-1-n { background-position: -80px -64px; }
.ui-icon-arrowreturn-1-e { background-position: -96px -64px; }
.ui-icon-arrowreturn-1-s { background-position: -112px -64px; }
.ui-icon-arrowrefresh-1-w { background-position: -128px -64px; }
.ui-icon-arrowrefresh-1-n { background-position: -144px -64px; }
.ui-icon-arrowrefresh-1-e { background-position: -160px -64px; }
.ui-icon-arrowrefresh-1-s { background-position: -176px -64px; }
.ui-icon-arrow-4 { background-position: 0 -80px; }
.ui-icon-arrow-4-diag { background-position: -16px -80px; }
.ui-icon-extlink { background-position: -32px -80px; }
.ui-icon-newwin { background-position: -48px -80px; }
.ui-icon-refresh { background-position: -64px -80px; }
.ui-icon-shuffle { background-position: -80px -80px; }
.ui-icon-transfer-e-w { background-position: -96px -80px; }
.ui-icon-transferthick-e-w { background-position: -112px -80px; }
.ui-icon-folder-collapsed { background-position: 0 -96px; }
.ui-icon-folder-open { background-position: -16px -96px; }
.ui-icon-document { background-position: -32px -96px; }
.ui-icon-document-b { background-position: -48px -96px; }
.ui-icon-note { background-position: -64px -96px; }
.ui-icon-mail-closed { background-position: -80px -96px; }
.ui-icon-mail-open { background-position: -96px -96px; }
.ui-icon-suitcase { background-position: -112px -96px; }
.ui-icon-comment { background-position: -128px -96px; }
.ui-icon-person { background-position: -144px -96px; }
.ui-icon-print { background-position: -160px -96px; }
.ui-icon-trash { background-position: -176px -96px; }
.ui-icon-locked { background-position: -192px -96px; }
.ui-icon-unlocked { background-position: -208px -96px; }
.ui-icon-bookmark { background-position: -224px -96px; }
.ui-icon-tag { background-position: -240px -96px; }
.ui-icon-home { background-position: 0 -112px; }
.ui-icon-flag { background-position: -16px -112px; }
.ui-icon-calendar { background-position: -32px -112px; }
.ui-icon-cart { background-position: -48px -112px; }
.ui-icon-pencil { background-position: -64px -112px; }
.ui-icon-clock { background-position: -80px -112px; }
.ui-icon-disk { background-position: -96px -112px; }
.ui-icon-calculator { background-position: -112px -112px; }
.ui-icon-zoomin { background-position: -128px -112px; }
.ui-icon-zoomout { background-position: -144px -112px; }
.ui-icon-search { background-position: -160px -112px; }
.ui-icon-wrench { background-position: -176px -112px; }
.ui-icon-gear { background-position: -192px -112px; }
.ui-icon-heart { background-position: -208px -112px; }
.ui-icon-star { background-position: -224px -112px; }
.ui-icon-link { background-position: -240px -112px; }
.ui-icon-cancel { background-position: 0 -128px; }
.ui-icon-plus { background-position: -16px -128px; }
.ui-icon-plusthick { background-position: -32px -128px; }
.ui-icon-minus { background-position: -48px -128px; }
.ui-icon-minusthick { background-position: -64px -128px; }
.ui-icon-close { background-position: -80px -128px; }
.ui-icon-closethick { background-position: -96px -128px; }
.ui-icon-key { background-position: -112px -128px; }
.ui-icon-lightbulb { background-position: -128px -128px; }
.ui-icon-scissors { background-position: -144px -128px; }
.ui-icon-clipboard { background-position: -160px -128px; }
.ui-icon-copy { background-position: -176px -128px; }
.ui-icon-contact { background-position: -192px -128px; }
.ui-icon-image { background-position: -208px -128px; }
.ui-icon-video { background-position: -224px -128px; }
.ui-icon-script { background-position: -240px -128px; }
.ui-icon-alert { background-position: 0 -144px; }
.ui-icon-info { background-position: -16px -144px; }
.ui-icon-notice { background-position: -32px -144px; }
.ui-icon-help { background-position: -48px -144px; }
.ui-icon-check { background-position: -64px -144px; }
.ui-icon-bullet { background-position: -80px -144px; }
.ui-icon-radio-on { background-position: -96px -144px; }
.ui-icon-radio-off { background-position: -112px -144px; }
.ui-icon-pin-w { background-position: -128px -144px; }
.ui-icon-pin-s { background-position: -144px -144px; }
.ui-icon-play { background-position: 0 -160px; }
.ui-icon-pause { background-position: -16px -160px; }
.ui-icon-seek-next { background-position: -32px -160px; }
.ui-icon-seek-prev { background-position: -48px -160px; }
.ui-icon-seek-end { background-position: -64px -160px; }
.ui-icon-seek-start { background-position: -80px -160px; }
/* ui-icon-seek-first is deprecated, use ui-icon-seek-start instead */
.ui-icon-seek-first { background-position: -80px -160px; }
.ui-icon-stop { background-position: -96px -160px; }
.ui-icon-eject { background-position: -112px -160px; }
.ui-icon-volume-off { background-position: -128px -160px; }
.ui-icon-volume-on { background-position: -144px -160px; }
.ui-icon-power { background-position: 0 -176px; }
.ui-icon-signal-diag { background-position: -16px -176px; }
.ui-icon-signal { background-position: -32px -176px; }
.ui-icon-battery-0 { background-position: -48px -176px; }
.ui-icon-battery-1 { background-position: -64px -176px; }
.ui-icon-battery-2 { background-position: -80px -176px; }
.ui-icon-battery-3 { background-position: -96px -176px; }
.ui-icon-circle-plus { background-position: 0 -192px; }
.ui-icon-circle-minus { background-position: -16px -192px; }
.ui-icon-circle-close { background-position: -32px -192px; }
.ui-icon-circle-triangle-e { background-position: -48px -192px; }
.ui-icon-circle-triangle-s { background-position: -64px -192px; }
.ui-icon-circle-triangle-w { background-position: -80px -192px; }
.ui-icon-circle-triangle-n { background-position: -96px -192px; }
.ui-icon-circle-arrow-e { background-position: -112px -192px; }
.ui-icon-circle-arrow-s { background-position: -128px -192px; }
.ui-icon-circle-arrow-w { background-position: -144px -192px; }
.ui-icon-circle-arrow-n { background-position: -160px -192px; }
.ui-icon-circle-zoomin { background-position: -176px -192px; }
.ui-icon-circle-zoomout { background-position: -192px -192px; }
.ui-icon-circle-check { background-position: -208px -192px; }
.ui-icon-circlesmall-plus { background-position: 0 -208px; }
.ui-icon-circlesmall-minus { background-position: -16px -208px; }
.ui-icon-circlesmall-close { background-position: -32px -208px; }
.ui-icon-squaresmall-plus { background-position: -48px -208px; }
.ui-icon-squaresmall-minus { background-position: -64px -208px; }
.ui-icon-squaresmall-close { background-position: -80px -208px; }
.ui-icon-grip-dotted-vertical { background-position: 0 -224px; }
.ui-icon-grip-dotted-horizontal { background-position: -16px -224px; }
.ui-icon-grip-solid-vertical { background-position: -32px -224px; }
.ui-icon-grip-solid-horizontal { background-position: -48px -224px; }
.ui-icon-gripsmall-diagonal-se { background-position: -64px -224px; }
.ui-icon-grip-diagonal-se { background-position: -80px -224px; }


/* Misc visuals
----------------------------------*/

/* Corner radius */
.ui-corner-all,
.ui-corner-top,
.ui-corner-left,
.ui-corner-tl {
	border-top-left-radius: 3px;
}
.ui-corner-all,
.ui-corner-top,
.ui-corner-right,
.ui-corner-tr {
	border-top-right-radius: 3px;
}
.ui-corner-all,
.ui-corner-bottom,
.ui-corner-left,
.ui-corner-bl {
	border-bottom-left-radius: 3px;
}
.ui-corner-all,
.ui-corner-bottom,
.ui-corner-right,
.ui-corner-br {
	border-bottom-right-radius: 3px;
}

/* Overlays */
.ui-widget-overlay {
	background: #aaaaaa;
	opacity: .3;
}
.ui-widget-shadow {
	box-shadow: 0px 0px 5px #666666;
}

:root:not([data-ink-color-scheme]),
[data-ink-color-scheme=light] {
  --if-high-contrast:  ;
  --if-dark:  ;
  --if-dark-only:  ;
  --if-light: initial;
  color-scheme: light
}
:root[data-ink-color-scheme=dark],
[data-ink-color-scheme=dark] {
  --if-high-contrast:  ;
  --if-dark: initial;
  --if-dark-only: initial;
  --if-light:  ;
  color-scheme: dark light
}
:root[data-ink-color-scheme=high-contrast],
[data-ink-color-scheme=high-contrast] {
  --if-high-contrast: initial;
  --if-dark: initial;
  --if-dark-only:  ;
  --if-light:  ;
  color-scheme: dark light
}
@media (prefers-color-scheme:light) {
  [data-ink-color-scheme=system] {
    --if-dark:  ;
    --if-dark-only:  ;
    --if-high-contrast:  ;
    --if-light: initial;
    color-scheme: light
  }
}
@media (prefers-color-scheme:dark) {
  [data-ink-color-scheme=system] {
    --if-dark: initial;
    --if-dark-only: initial;
    --if-light:  ;
    color-scheme: dark light
  }
}
@media (prefers-contrast:more) {
  [data-ink-color-scheme=system] {
    --if-dark: initial;
    --if-dark-only:  ;
    --if-high-contrast: initial;
    --if-light:  ;
    color-scheme: dark light
  }
}
:root {
  --ink-p-light__black: #000000;
  --ink-p-light__white: #FFFFFF;
  --ink-p-light__grey-100: #F9F9F9;
  --ink-p-light__grey-150: #F3F3F3;
  --ink-p-light__grey-200: #E9E9E9;
  --ink-p-light__grey-300: #D0D0D0;
  --ink-p-light__grey-400: #C0C0C0;
  --ink-p-light__grey-450: #B1AFAF;
  --ink-p-light__grey-500: #999999;
  --ink-p-light__grey-600: #777777;
  --ink-p-light__grey-700: #555555;
  --ink-p-light__grey-800: #444444;
  --ink-p-light__grey-900: #333333;
  --ink-p-light__blue-100: #F2FAFF;
  --ink-p-light__blue-200: #DAEBFF;
  --ink-p-light__blue-300: #D0E6FF;
  --ink-p-light__blue-400: #B0D0FF;
  --ink-p-light__blue-500: #88B9FF;
  --ink-p-light__blue-600: #4A90E2;
  --ink-p-light__blue-700: #0174E8;
  --ink-p-light__blue-800: #124BBD;
  --ink-p-light__blue-900: #102640;
  --ink-p-light__brown-100: #FEE7D4;
  --ink-p-light__brown-200: #F2CDB4;
  --ink-p-light__brown-300: #DCAC8E;
  --ink-p-light__brown-400: #C88E6B;
  --ink-p-light__brown-500: #A9704F;
  --ink-p-light__brown-600: #895A40;
  --ink-p-light__brown-700: #6B450F;
  --ink-p-light__brown-800: #57370B;
  --ink-p-light__brown-900: #4B320F;
  --ink-p-light__cool-grey-100: #F8F9FB;
  --ink-p-light__cool-grey-200: #E4E9EF;
  --ink-p-light__cool-grey-300: #C4CFDC;
  --ink-p-light__cool-grey-400: #B0BFD0;
  --ink-p-light__cool-grey-500: #8097B3;
  --ink-p-light__cool-grey-600: #597595;
  --ink-p-light__cool-grey-700: #40546A;
  --ink-p-light__cool-grey-800: #334355;
  --ink-p-light__cool-grey-900: #263240;
  --ink-p-light__cyan-100: #F1FDFF;
  --ink-p-light__cyan-200: #C8F8FF;
  --ink-p-light__cyan-300: #8DF0FF;
  --ink-p-light__cyan-400: #49E2FA;
  --ink-p-light__cyan-500: #03BCD9;
  --ink-p-light__cyan-600: #0194AB;
  --ink-p-light__cyan-700: #036F80;
  --ink-p-light__cyan-800: #004A55;
  --ink-p-light__cyan-900: #013239;
  --ink-p-light__green-100: #EDFBDD;
  --ink-p-light__green-200: #D1F5A9;
  --ink-p-light__green-300: #93EE6F;
  --ink-p-light__green-400: #65E62D;
  --ink-p-light__green-500: #49BB18;
  --ink-p-light__green-600: #479623;
  --ink-p-light__green-700: #357915;
  --ink-p-light__green-800: #226611;
  --ink-p-light__green-900: #0D570D;
  --ink-p-light__mustard-100: #FCF9E9;
  --ink-p-light__mustard-200: #F1E9BE;
  --ink-p-light__mustard-300: #E5DA9A;
  --ink-p-light__mustard-400: #E0CF7B;
  --ink-p-light__mustard-500: #D0BD30;
  --ink-p-light__mustard-600: #BCA626;
  --ink-p-light__mustard-700: #9D8B06;
  --ink-p-light__mustard-800: #7A7012;
  --ink-p-light__mustard-900: #575022;
  --ink-p-light__red-100: #FFE0E5;
  --ink-p-light__red-200: #F6A8A8;
  --ink-p-light__red-300: #F06C6C;
  --ink-p-light__red-400: #EA3939;
  --ink-p-light__red-500: #DE1717;
  --ink-p-light__red-600: #C10E0E;
  --ink-p-light__red-700: #A31111;
  --ink-p-light__red-800: #7E0D0D;
  --ink-p-light__red-900: #610A0A;
  --ink-p-light__yellow-100: #FFFBE9;
  --ink-p-light__yellow-200: #FFF7CD;
  --ink-p-light__yellow-300: #FFF4B0;
  --ink-p-light__yellow-400: #FFEF72;
  --ink-p-light__yellow-500: #FFEB35;
  --ink-p-light__yellow-600: #F9E000;
  --ink-p-light__yellow-700: #F0D800;
  --ink-p-light__yellow-800: #D3BE00;
  --ink-p-light__yellow-900: #AD9C00;
  --ink-p-dark__black: #000000;
  --ink-p-dark__white: #FFFFFF;
  --ink-p-dark__grey-100: #333333;
  --ink-p-dark__grey-150: #4C4C4C;
  --ink-p-dark__grey-200: #444444;
  --ink-p-dark__grey-300: #555555;
  --ink-p-dark__grey-400: #777777;
  --ink-p-dark__grey-450: #999999;
  --ink-p-dark__grey-500: #B1AFAF;
  --ink-p-dark__grey-600: #C0C0C0;
  --ink-p-dark__grey-700: #D0D0D0;
  --ink-p-dark__grey-800: #E9E9E9;
  --ink-p-dark__grey-900: #F9F9F9;
  --ink-p-dark__blue-100: #102640;
  --ink-p-dark__blue-200: #124BBD;
  --ink-p-dark__blue-300: #2378DB;
  --ink-p-dark__blue-400: #4A90E2;
  --ink-p-dark__blue-500: #88B9FF;
  --ink-p-dark__blue-600: #B0D0FF;
  --ink-p-dark__blue-700: #D0E6FF;
  --ink-p-dark__blue-800: #DAEBFF;
  --ink-p-dark__blue-900: #F2FAFF;
  --ink-p-dark__brown-100: #4B320F;
  --ink-p-dark__brown-200: #57370B;
  --ink-p-dark__brown-300: #6B450F;
  --ink-p-dark__brown-400: #895A40;
  --ink-p-dark__brown-500: #A9704F;
  --ink-p-dark__brown-600: #C88E6B;
  --ink-p-dark__brown-700: #DCAC8E;
  --ink-p-dark__brown-800: #F2CDB4;
  --ink-p-dark__brown-900: #FEE7D4;
  --ink-p-dark__cool-grey-100: #263240;
  --ink-p-dark__cool-grey-200: #334355;
  --ink-p-dark__cool-grey-300: #40546A;
  --ink-p-dark__cool-grey-400: #597595;
  --ink-p-dark__cool-grey-500: #8097B3;
  --ink-p-dark__cool-grey-600: #B0BFD0;
  --ink-p-dark__cool-grey-700: #C4CFDC;
  --ink-p-dark__cool-grey-800: #E4E9EF;
  --ink-p-dark__cool-grey-900: #F8F9FB;
  --ink-p-dark__cyan-100: #013239;
  --ink-p-dark__cyan-200: #004A55;
  --ink-p-dark__cyan-300: #036F80;
  --ink-p-dark__cyan-400: #0194AB;
  --ink-p-dark__cyan-500: #03BCD9;
  --ink-p-dark__cyan-600: #49E2FA;
  --ink-p-dark__cyan-700: #8DF0FF;
  --ink-p-dark__cyan-800: #C8F8FF;
  --ink-p-dark__cyan-900: #F1FDFF;
  --ink-p-dark__green-100: #0D570D;
  --ink-p-dark__green-200: #226611;
  --ink-p-dark__green-300: #357915;
  --ink-p-dark__green-400: #479623;
  --ink-p-dark__green-500: #49BB18;
  --ink-p-dark__green-600: #65E62D;
  --ink-p-dark__green-700: #93EE6F;
  --ink-p-dark__green-800: #D1F5A9;
  --ink-p-dark__green-900: #EDFBDD;
  --ink-p-dark__mustard-100: #575022;
  --ink-p-dark__mustard-200: #7A7012;
  --ink-p-dark__mustard-300: #9D8B06;
  --ink-p-dark__mustard-400: #BCA626;
  --ink-p-dark__mustard-500: #D0BD30;
  --ink-p-dark__mustard-600: #E0CF7B;
  --ink-p-dark__mustard-700: #E5DA9A;
  --ink-p-dark__mustard-800: #F1E9BE;
  --ink-p-dark__mustard-900: #FCF9E9;
  --ink-p-dark__red-100: #610A0A;
  --ink-p-dark__red-200: #7E0D0D;
  --ink-p-dark__red-300: #A31111;
  --ink-p-dark__red-400: #C10E0E;
  --ink-p-dark__red-500: #DE1717;
  --ink-p-dark__red-600: #EA3939;
  --ink-p-dark__red-700: #F06C6C;
  --ink-p-dark__red-800: #F6A8A8;
  --ink-p-dark__red-900: #FFE0E5;
  --ink-p-dark__yellow-100: #AD9C00;
  --ink-p-dark__yellow-200: #D3BE00;
  --ink-p-dark__yellow-300: #F0D800;
  --ink-p-dark__yellow-400: #F9E000;
  --ink-p-dark__yellow-500: #FFEB35;
  --ink-p-dark__yellow-600: #FFEF72;
  --ink-p-dark__yellow-700: #FFF4B0;
  --ink-p-dark__yellow-800: #FFF7CD;
  --ink-p-dark__yellow-900: #FFFBE9;
  --ink-c-data-table-border-color: var(--if-dark, var(--ink-p-container-border-color)) var(--if-light, var(--ink-p-container-border-color));
  --ink-c-data-table-border: var(--ink-u-border-thin) var(--ink-c-data-table-border-color) solid;
  --ink-c-data-table-cell-padding-vert: var(--ink-u-spacing-s);
  --ink-c-data-table-cell-padding-horiz: var(--ink-u-spacing-sm);
  --ink-c-data-table-cell-padding: var(--ink-c-data-table-cell-padding-vert) var(--ink-c-data-table-cell-padding-horiz);
  --ink-c-data-table-header-bg: var(--ink-p-header-bg);
  --ink-c-data-table-header-fg: var(--ink-p-header-fg);
  --ink-c-data-table-header-hover-fg: var(--ink-p-link-fg);
  --ink-c-data-table-body-bg: var(--if-dark, #161616) var(--if-light, white);
  --ink-c-data-table-body-fg: var(--if-dark, var(--ink-p-grey-900)) var(--if-light, var(--ink-p-fg));
  --ink-c-data-table-row-border-color: var(--if-dark, rgba(255, 255, 255, 0.08)) var(--if-light, rgba(0, 0, 0, 0.08));
  --ink-c-data-table-row-border: var(--ink-u-border-thin) var(--ink-c-data-table-row-border-color) solid;
  --ink-c-data-table-row-bg: transparent;
  --ink-c-data-table-row-alt-bg: var(--if-dark, rgba(255, 255, 255, 0.02)) var(--if-light, rgba(0, 0, 0, 0.01));
  --ink-c-data-table-unsort-icon: var(--ink-i-close)
}
:root .ink-i-add {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-add);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-arrow-left {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-arrow-left);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-arrow-left-first {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-arrow-left-first);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-arrow-right {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-arrow-right);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-arrow-right-first {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-arrow-right-first);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-check {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-check);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-circle-arrow-right {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-circle-arrow-right);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-clock {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-clock);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-close {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-close);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-copy {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-copy);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-delete-item {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-delete-item);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-dot {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-dot);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-dropdown {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-dropdown);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-error {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-error);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-help {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-help);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-info {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-info);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-mobile-menu {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-mobile-menu);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-refresh {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-refresh);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-search {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-search);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-settings {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-settings);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-sort-ascending {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-sort-ascending);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-sort-descending {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-sort-descending);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-success {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-success);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-unsort {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-unsort);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-user {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-user);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-vcs-commit {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-vcs-commit);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-warning {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-warning);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-zoom-in {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-zoom-in);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root .ink-i-zoom-out {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-i-zoom-out);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
:root,
[data-ink-color-scheme] {
  --ink-p-black: var(--if-dark, var(--ink-p-dark__black)) var(--if-light, var(--ink-p-light__black));
  --ink-p-white: var(--if-dark, var(--ink-p-dark__white)) var(--if-light, var(--ink-p-light__white));
  --ink-p-grey-100: var(--if-dark, var(--ink-p-dark__grey-100)) var(--if-light, var(--ink-p-light__grey-100));
  --ink-p-grey-150: var(--if-dark, var(--ink-p-dark__grey-150)) var(--if-light, var(--ink-p-light__grey-150));
  --ink-p-grey-200: var(--if-dark, var(--ink-p-dark__grey-200)) var(--if-light, var(--ink-p-light__grey-200));
  --ink-p-grey-300: var(--if-dark, var(--ink-p-dark__grey-300)) var(--if-light, var(--ink-p-light__grey-300));
  --ink-p-grey-400: var(--if-dark, var(--ink-p-dark__grey-400)) var(--if-light, var(--ink-p-light__grey-400));
  --ink-p-grey-450: var(--if-dark, var(--ink-p-dark__grey-450)) var(--if-light, var(--ink-p-light__grey-450));
  --ink-p-grey-500: var(--if-dark, var(--ink-p-dark__grey-500)) var(--if-light, var(--ink-p-light__grey-500));
  --ink-p-grey-600: var(--if-dark, var(--ink-p-dark__grey-600)) var(--if-light, var(--ink-p-light__grey-600));
  --ink-p-grey-700: var(--if-dark, var(--ink-p-dark__grey-700)) var(--if-light, var(--ink-p-light__grey-700));
  --ink-p-grey-800: var(--if-dark, var(--ink-p-dark__grey-800)) var(--if-light, var(--ink-p-light__grey-800));
  --ink-p-grey-900: var(--if-dark, var(--ink-p-dark__grey-900)) var(--if-light, var(--ink-p-light__grey-900));
  --ink-p-blue-100: var(--if-dark, var(--ink-p-dark__blue-100)) var(--if-light, var(--ink-p-light__blue-100));
  --ink-p-blue-200: var(--if-dark, var(--ink-p-dark__blue-200)) var(--if-light, var(--ink-p-light__blue-200));
  --ink-p-blue-300: var(--if-dark, var(--ink-p-dark__blue-300)) var(--if-light, var(--ink-p-light__blue-300));
  --ink-p-blue-400: var(--if-dark, var(--ink-p-dark__blue-400)) var(--if-light, var(--ink-p-light__blue-400));
  --ink-p-blue-500: var(--if-dark, var(--ink-p-dark__blue-500)) var(--if-light, var(--ink-p-light__blue-500));
  --ink-p-blue-600: var(--if-dark, var(--ink-p-dark__blue-600)) var(--if-light, var(--ink-p-light__blue-600));
  --ink-p-blue-700: var(--if-dark, var(--ink-p-dark__blue-700)) var(--if-light, var(--ink-p-light__blue-700));
  --ink-p-blue-800: var(--if-dark, var(--ink-p-dark__blue-800)) var(--if-light, var(--ink-p-light__blue-800));
  --ink-p-blue-900: var(--if-dark, var(--ink-p-dark__blue-900)) var(--if-light, var(--ink-p-light__blue-900));
  --ink-p-brown-100: var(--if-dark, var(--ink-p-dark__brown-100)) var(--if-light, var(--ink-p-light__brown-100));
  --ink-p-brown-200: var(--if-dark, var(--ink-p-dark__brown-200)) var(--if-light, var(--ink-p-light__brown-200));
  --ink-p-brown-300: var(--if-dark, var(--ink-p-dark__brown-300)) var(--if-light, var(--ink-p-light__brown-300));
  --ink-p-brown-400: var(--if-dark, var(--ink-p-dark__brown-400)) var(--if-light, var(--ink-p-light__brown-400));
  --ink-p-brown-500: var(--if-dark, var(--ink-p-dark__brown-500)) var(--if-light, var(--ink-p-light__brown-500));
  --ink-p-brown-600: var(--if-dark, var(--ink-p-dark__brown-600)) var(--if-light, var(--ink-p-light__brown-600));
  --ink-p-brown-700: var(--if-dark, var(--ink-p-dark__brown-700)) var(--if-light, var(--ink-p-light__brown-700));
  --ink-p-brown-800: var(--if-dark, var(--ink-p-dark__brown-800)) var(--if-light, var(--ink-p-light__brown-800));
  --ink-p-brown-900: var(--if-dark, var(--ink-p-dark__brown-900)) var(--if-light, var(--ink-p-light__brown-900));
  --ink-p-cool-grey-100: var(--if-dark, var(--ink-p-dark__cool-grey-100)) var(--if-light, var(--ink-p-light__cool-grey-100));
  --ink-p-cool-grey-200: var(--if-dark, var(--ink-p-dark__cool-grey-200)) var(--if-light, var(--ink-p-light__cool-grey-200));
  --ink-p-cool-grey-300: var(--if-dark, var(--ink-p-dark__cool-grey-300)) var(--if-light, var(--ink-p-light__cool-grey-300));
  --ink-p-cool-grey-400: var(--if-dark, var(--ink-p-dark__cool-grey-400)) var(--if-light, var(--ink-p-light__cool-grey-400));
  --ink-p-cool-grey-500: var(--if-dark, var(--ink-p-dark__cool-grey-500)) var(--if-light, var(--ink-p-light__cool-grey-500));
  --ink-p-cool-grey-600: var(--if-dark, var(--ink-p-dark__cool-grey-600)) var(--if-light, var(--ink-p-light__cool-grey-600));
  --ink-p-cool-grey-700: var(--if-dark, var(--ink-p-dark__cool-grey-700)) var(--if-light, var(--ink-p-light__cool-grey-700));
  --ink-p-cool-grey-800: var(--if-dark, var(--ink-p-dark__cool-grey-800)) var(--if-light, var(--ink-p-light__cool-grey-800));
  --ink-p-cool-grey-900: var(--if-dark, var(--ink-p-dark__cool-grey-900)) var(--if-light, var(--ink-p-light__cool-grey-900));
  --ink-p-cyan-100: var(--if-dark, var(--ink-p-dark__cyan-100)) var(--if-light, var(--ink-p-light__cyan-100));
  --ink-p-cyan-200: var(--if-dark, var(--ink-p-dark__cyan-200)) var(--if-light, var(--ink-p-light__cyan-200));
  --ink-p-cyan-300: var(--if-dark, var(--ink-p-dark__cyan-300)) var(--if-light, var(--ink-p-light__cyan-300));
  --ink-p-cyan-400: var(--if-dark, var(--ink-p-dark__cyan-400)) var(--if-light, var(--ink-p-light__cyan-400));
  --ink-p-cyan-500: var(--if-dark, var(--ink-p-dark__cyan-500)) var(--if-light, var(--ink-p-light__cyan-500));
  --ink-p-cyan-600: var(--if-dark, var(--ink-p-dark__cyan-600)) var(--if-light, var(--ink-p-light__cyan-600));
  --ink-p-cyan-700: var(--if-dark, var(--ink-p-dark__cyan-700)) var(--if-light, var(--ink-p-light__cyan-700));
  --ink-p-cyan-800: var(--if-dark, var(--ink-p-dark__cyan-800)) var(--if-light, var(--ink-p-light__cyan-800));
  --ink-p-cyan-900: var(--if-dark, var(--ink-p-dark__cyan-900)) var(--if-light, var(--ink-p-light__cyan-900));
  --ink-p-green-100: var(--if-dark, var(--ink-p-dark__green-100)) var(--if-light, var(--ink-p-light__green-100));
  --ink-p-green-200: var(--if-dark, var(--ink-p-dark__green-200)) var(--if-light, var(--ink-p-light__green-200));
  --ink-p-green-300: var(--if-dark, var(--ink-p-dark__green-300)) var(--if-light, var(--ink-p-light__green-300));
  --ink-p-green-400: var(--if-dark, var(--ink-p-dark__green-400)) var(--if-light, var(--ink-p-light__green-400));
  --ink-p-green-500: var(--if-dark, var(--ink-p-dark__green-500)) var(--if-light, var(--ink-p-light__green-500));
  --ink-p-green-600: var(--if-dark, var(--ink-p-dark__green-600)) var(--if-light, var(--ink-p-light__green-600));
  --ink-p-green-700: var(--if-dark, var(--ink-p-dark__green-700)) var(--if-light, var(--ink-p-light__green-700));
  --ink-p-green-800: var(--if-dark, var(--ink-p-dark__green-800)) var(--if-light, var(--ink-p-light__green-800));
  --ink-p-green-900: var(--if-dark, var(--ink-p-dark__green-900)) var(--if-light, var(--ink-p-light__green-900));
  --ink-p-mustard-100: var(--if-dark, var(--ink-p-dark__mustard-100)) var(--if-light, var(--ink-p-light__mustard-100));
  --ink-p-mustard-200: var(--if-dark, var(--ink-p-dark__mustard-200)) var(--if-light, var(--ink-p-light__mustard-200));
  --ink-p-mustard-300: var(--if-dark, var(--ink-p-dark__mustard-300)) var(--if-light, var(--ink-p-light__mustard-300));
  --ink-p-mustard-400: var(--if-dark, var(--ink-p-dark__mustard-400)) var(--if-light, var(--ink-p-light__mustard-400));
  --ink-p-mustard-500: var(--if-dark, var(--ink-p-dark__mustard-500)) var(--if-light, var(--ink-p-light__mustard-500));
  --ink-p-mustard-600: var(--if-dark, var(--ink-p-dark__mustard-600)) var(--if-light, var(--ink-p-light__mustard-600));
  --ink-p-mustard-700: var(--if-dark, var(--ink-p-dark__mustard-700)) var(--if-light, var(--ink-p-light__mustard-700));
  --ink-p-mustard-800: var(--if-dark, var(--ink-p-dark__mustard-800)) var(--if-light, var(--ink-p-light__mustard-800));
  --ink-p-mustard-900: var(--if-dark, var(--ink-p-dark__mustard-900)) var(--if-light, var(--ink-p-light__mustard-900));
  --ink-p-red-100: var(--if-dark, var(--ink-p-dark__red-100)) var(--if-light, var(--ink-p-light__red-100));
  --ink-p-red-200: var(--if-dark, var(--ink-p-dark__red-200)) var(--if-light, var(--ink-p-light__red-200));
  --ink-p-red-300: var(--if-dark, var(--ink-p-dark__red-300)) var(--if-light, var(--ink-p-light__red-300));
  --ink-p-red-400: var(--if-dark, var(--ink-p-dark__red-400)) var(--if-light, var(--ink-p-light__red-400));
  --ink-p-red-500: var(--if-dark, var(--ink-p-dark__red-500)) var(--if-light, var(--ink-p-light__red-500));
  --ink-p-red-600: var(--if-dark, var(--ink-p-dark__red-600)) var(--if-light, var(--ink-p-light__red-600));
  --ink-p-red-700: var(--if-dark, var(--ink-p-dark__red-700)) var(--if-light, var(--ink-p-light__red-700));
  --ink-p-red-800: var(--if-dark, var(--ink-p-dark__red-800)) var(--if-light, var(--ink-p-light__red-800));
  --ink-p-red-900: var(--if-dark, var(--ink-p-dark__red-900)) var(--if-light, var(--ink-p-light__red-900));
  --ink-p-yellow-100: var(--if-dark, var(--ink-p-dark__yellow-100)) var(--if-light, var(--ink-p-light__yellow-100));
  --ink-p-yellow-200: var(--if-dark, var(--ink-p-dark__yellow-200)) var(--if-light, var(--ink-p-light__yellow-200));
  --ink-p-yellow-300: var(--if-dark, var(--ink-p-dark__yellow-300)) var(--if-light, var(--ink-p-light__yellow-300));
  --ink-p-yellow-400: var(--if-dark, var(--ink-p-dark__yellow-400)) var(--if-light, var(--ink-p-light__yellow-400));
  --ink-p-yellow-500: var(--if-dark, var(--ink-p-dark__yellow-500)) var(--if-light, var(--ink-p-light__yellow-500));
  --ink-p-yellow-600: var(--if-dark, var(--ink-p-dark__yellow-600)) var(--if-light, var(--ink-p-light__yellow-600));
  --ink-p-yellow-700: var(--if-dark, var(--ink-p-dark__yellow-700)) var(--if-light, var(--ink-p-light__yellow-700));
  --ink-p-yellow-800: var(--if-dark, var(--ink-p-dark__yellow-800)) var(--if-light, var(--ink-p-light__yellow-800));
  --ink-p-yellow-900: var(--if-dark, var(--ink-p-dark__yellow-900)) var(--if-light, var(--ink-p-light__yellow-900));
  --ink-p-surface-bg: var(--if-dark, #313338) var(--if-light, var(--ink-p-grey-100));
  --ink-p-surface-bright-bg: var(--if-dark, #313338) var(--if-light, var(--ink-p-white));
  --ink-p-surface-dim-bg: var(--if-dark, #313338) var(--if-light, var(--ink-p-grey-200));
  --ink-p-surface-fg: var(--ink-p-fg);
  --ink-p-surface-fg-weak: var(--ink-p-fg-weak);
  --ink-p-container-bg: var(--if-dark, #282828) var(--if-light, var(--ink-p-grey-100));
  --ink-p-container-active-bg: var(--if-dark, rgba(255, 255, 255, 0.12)) var(--if-light, rgba(0, 0, 0, 0.12));
  --ink-p-container-hover-bg: var(--if-dark, rgba(255, 255, 255, 0.05)) var(--if-light, rgba(0, 0, 0, 0.05));
  --ink-p-container-fg: var(--ink-p-surface-fg);
  --ink-p-container-fg-weak: var(--ink-p-surface-fg-weak);
  --ink-p-container-border-color: var(--if-dark, rgba(255, 255, 255, 0.2)) var(--if-light, rgba(0, 0, 0, 0.3));
  --ink-p-container-border-color-strong: var(--if-dark, rgba(255, 255, 255, 0.4)) var(--if-light, rgba(0, 0, 0, 0.4));
  --ink-p-container-border-color-weak: var(--if-dark, rgba(255, 255, 255, 0.1)) var(--if-light, rgba(0, 0, 0, 0.2));
  --ink-p-accent-primary-bg: var(--if-dark, var(--ink-p-blue-300)) var(--if-light, var(--ink-p-blue-700));
  --ink-p-accent-secondary-bg: var(--if-dark, var(--ink-p-blue-400)) var(--if-light, var(--ink-p-blue-600));
  --ink-p-accent-tertiary-bg: var(--if-dark, var(--ink-p-blue-500)) var(--if-light, var(--ink-p-blue-500));
  --ink-p-accent-success-bg: var(--ink-p-light__green-200);
  --ink-p-accent-error-bg: var(--ink-p-light__red-100);
  --ink-p-accent-warning-bg: var(--ink-p-light__yellow-300);
  --ink-p-accent-info-bg: var(--ink-p-light__blue-200);
  --ink-p-accent-highlight-bg: var(--ink-p-light__yellow-200);
  --ink-p-accent-primary-fg: var(--ink-p-fg-on-dark);
  --ink-p-accent-secondary-fg: var(--ink-p-fg-on-dark);
  --ink-p-accent-tertiary-fg: var(--ink-p-fg-on-light);
  --ink-p-accent-success-fg: var(--ink-p-fg-on-light);
  --ink-p-accent-error-fg: var(--ink-p-fg-on-light);
  --ink-p-accent-warning-fg: var(--ink-p-fg-on-light);
  --ink-p-accent-info-fg: var(--ink-p-fg-on-light);
  --ink-p-accent-highlight-fg: var(--ink-p-fg-on-light);
  --ink-p-accent-success-fg-on-container: var(--ink-p-green-800);
  --ink-p-accent-error-fg-on-container: var(--if-dark, var(--ink-p-red-800)) var(--if-light, var(--ink-p-red-600));
  --ink-p-accent-highlight-fg-on-container: var(--if-dark, var(--ink-p-yellow-500)) var(--if-light, var(--ink-p-brown-800));
  --ink-p-accent-primary-border-color: var(--ink-p-container-border-color);
  --ink-p-accent-secondary-border-color: var(--ink-p-container-border-color);
  --ink-p-accent-tertiary-border-color: var(--ink-p-container-border-color);
  --ink-p-accent-success-border-color: var(--ink-p-container-border-color);
  --ink-p-accent-error-border-color: rgba(0, 0, 0, 0.2);
  --ink-p-accent-warning-border-color: rgba(0, 0, 0, 0.2);
  --ink-p-accent-info-border-color: var(--ink-p-container-border-color);
  --ink-p-accent-highlight-border-color: var(--ink-p-container-border-color);
  --ink-p-page-bg: var(--ink-p-surface-bg);
  --ink-p-fg-on-dark: var(--ink-p-white);
  --ink-p-fg-on-light: var(--ink-p-black);
  --ink-p-fg-weak-on-dark: rgba(255, 255, 255, 0.75);
  --ink-p-fg-weak-on-light: rgba(0, 0, 0, 0.5);
  --ink-p-fg: var(--if-dark, var(--ink-p-fg-on-dark)) var(--if-light, var(--ink-p-fg-on-light));
  --ink-p-fg-weak: var(--if-dark, var(--ink-p-fg-weak-on-dark)) var(--if-light, var(--ink-p-fg-weak-on-light));
  --ink-p-link-fg-on-light: var(--ink-p-light__blue-800);
  --ink-p-link-fg-on-dark: #AEC9FF;
  --ink-p-link-hover-fg-on-light: #0e398e;
  --ink-p-link-hover-fg-on-dark: #e1ebff;
  --ink-p-link-fg: var(--if-dark, var(--ink-p-link-fg-on-dark)) var(--if-light, var(--ink-p-link-fg-on-light));
  --ink-p-link-hover-fg: var(--if-dark, var(--ink-p-link-hover-fg-on-dark)) var(--if-light, var(--ink-p-link-hover-fg-on-light));
  --ink-p-icon-color: var(--ink-p-fg);
  --ink-p-header-bg: var(--if-dark, #1E1F22) var(--if-light, var(--ink-p-blue-300));
  --ink-p-header-border-color: var(--ink-p-container-border-color);
  --ink-p-header-fg: var(--if-dark, var(--ink-p-fg-on-dark)) var(--if-light, var(--ink-p-accent-tertiary-fg));
  --ink-p-header-fg-weak: var(--ink-p-fg-weak);
  --ink-p-footer-bg: var(--if-dark, var(--ink-p-header-bg)) var(--if-light, var(--ink-p-grey-200));
  --ink-p-footer-border-color: var(--ink-p-container-border-color);
  --ink-p-footer-fg: var(--if-dark, var(--ink-p-header-fg)) var(--if-light, var(--ink-p-surface-fg));
  --ink-p-input-bg: var(--if-dark, #282F32) var(--if-light, var(--ink-p-white));
  --ink-p-input-border-color: var(--if-dark, var(--ink-p-black)) var(--if-light, var(--ink-p-grey-400));
  --ink-p-input-fg: var(--if-dark, var(--ink-p-fg-on-dark)) var(--if-light, var(--ink-p-fg-on-light));
  --ink-p-input-selection-bg: var(--if-dark, rgba(200, 108, 255, 0.2)) var(--if-light, rgba(0, 128, 255, 0.2));
  --ink-p-accent-default-bg: var(--if-dark, #1E1F22) var(--if-light, var(--ink-p-blue-300));
  --ink-p-accent-default-border-color: var(--ink-p-header-border-color);
  --ink-p-code-literal-bg: var(--if-dark, inherit) var(--if-light, var(--ink-p-grey-100));
  --ink-p-code-literal-fg: var(--if-dark, var(--ink-p-red-800)) var(--if-light, var(--ink-p-red-700));
  --ink-p-code-literal-border-color: var(--if-dark, rgba(255, 255, 255, 0.15)) var(--if-light, rgba(0, 0, 0, 0.1));
  --ink-p-side-panel-bg: var(--if-dark, var(--ink-p-grey-100)) var(--if-light, var(--ink-p-grey-150));
  --ink-p-side-panel-active-bg: var(--if-dark, rgba(255, 255, 255, 0.12)) var(--if-light, rgba(0, 0, 0, 0.12));
  --ink-p-side-panel-hover-bg: var(--if-dark, rgba(255, 255, 255, 0.05)) var(--if-light, rgba(0, 0, 0, 0.05));
  --ink-p-side-panel-fg: var(--if-dark, var(--ink-p-fg-on-dark)) var(--if-light, var(--ink-p-fg-on-light));
  --ink-p-side-panel-border-color: var(--if-dark, rgba(255, 255, 255, 0.2)) var(--if-light, rgba(0, 0, 0, 0.2));
  --ink-u-border-radius-scale: 8px;
  --ink-u-border-radius-xs: 2px;
  --ink-u-border-radius-s-inner: 3px;
  --ink-u-border-radius-s: 4px;
  --ink-u-border-radius-m-inner: 7px;
  --ink-u-border-radius-m: 8px;
  --ink-u-border-radius-l: 10px;
  --ink-u-border-radius-xl: 16px;
  --ink-u-border-radius-xxl: 32px;
  --ink-u-border-radius-std: var(--ink-u-border-radius-s);
  --ink-u-border-radius-container: var(--ink-u-border-radius-std);
  --ink-u-border-radius-input: var(--ink-u-border-radius-std);
  --ink-u-border-x-thin: 0.5px;
  --ink-u-border-thin: 1px;
  --ink-u-border-medium: 2px;
  --ink-u-border-thick: 4px;
  --ink-u-font-xs: var(--ink-u-rem-10px);
  --ink-u-font-s: var(--ink-u-rem-11px);
  --ink-u-font-sm: var(--ink-u-rem-12px);
  --ink-u-font-m: var(--ink-u-rem-13px);
  --ink-u-font-ml: var(--ink-u-rem-14px);
  --ink-u-font-l: var(--ink-u-rem-16px);
  --ink-u-font-std: var(--ink-u-font-m);
  --ink-u-icon-scale: 16px;
  --ink-u-icon-s: 8px;
  --ink-u-icon-sm: 12px;
  --ink-u-icon-m: 16px;
  --ink-u-icon-ml: 20px;
  --ink-u-icon-l: 24px;
  --ink-u-icon-xl: 32px;
  --ink-u-icon-std: var(--ink-u-icon-m);
  --ink-u-rem-10px: 0.625rem;
  --ink-u-rem-11px: 0.6875rem;
  --ink-u-rem-12px: 0.75rem;
  --ink-u-rem-13px: 0.8125rem;
  --ink-u-rem-14px: 0.875rem;
  --ink-u-rem-16px: 1rem;
  --ink-u-spacing-scale: 1em;
  --ink-u-spacing-xs: 0.25em;
  --ink-u-spacing-s: 0.5em;
  --ink-u-spacing-sm: 0.75em;
  --ink-u-spacing-m: 1em;
  --ink-u-spacing-ml: 1.5em;
  --ink-u-spacing-l: 2em;
  --ink-u-spacing-xl: 3em;
  --ink-u-spacing-xxl: 4em;
  --ink-u-spacing-std: var(--ink-u-spacing-m);
  --ink-ff-default: var(--ink-ff-sans-serif);
  --ink-ff-monospace: "SF Mono",SFMono-Regular,ui-monospace,Menlo,Monaco,Consolas,"Liberation Mono","Courier New",monospace;
  --ink-ff-sans-serif: DejaVu Sans,Verdana,Arial,Helvetica,Sans-Serif;
  --ink-ff-serif: Georgia,Cambria,"Times New Roman",Times,serif;
  --ink-i-add: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-circle-plus%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M4.929%204.929a10%2010%200%201%201%2014.141%2014.141a10%2010%200%200%201%20-14.14%20-14.14zm8.071%204.071a1%201%200%201%200%20-2%200v2h-2a1%201%200%201%200%200%202h2v2a1%201%200%201%200%202%200v-2h2a1%201%200%201%200%200%20-2h-2v-2z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-arrow-left: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-arrow-big-left%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M9.586%204l-6.586%206.586a2%202%200%200%200%200%202.828l6.586%206.586a2%202%200%200%200%202.18%20.434l.145%20-.068a2%202%200%200%200%201.089%20-1.78v-2.586h7a2%202%200%200%200%202%20-2v-4l-.005%20-.15a2%202%200%200%200%20-1.995%20-1.85l-7%20-.001v-2.585a2%202%200%200%200%20-3.414%20-1.414z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-arrow-left-first: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-arrow-badge-left%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M17%206h-6a1%201%200%200%200%20-.78%20.375l-4%205a1%201%200%200%200%200%201.25l4%205a1%201%200%200%200%20.78%20.375h6l.112%20-.006a1%201%200%200%200%20.669%20-1.619l-3.501%20-4.375l3.5%20-4.375a1%201%200%200%200%20-.78%20-1.625z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-arrow-right: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-arrow-big-right%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M12.089%203.634a2%202%200%200%200%20-1.089%201.78l-.001%202.586h-6.999a2%202%200%200%200%20-2%202v4l.005%20.15a2%202%200%200%200%201.995%201.85l6.999%20-.001l.001%202.587a2%202%200%200%200%203.414%201.414l6.586%20-6.586a2%202%200%200%200%200%20-2.828l-6.586%20-6.586a2%202%200%200%200%20-2.18%20-.434l-.145%20.068z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-arrow-right-first: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-arrow-badge-right%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M7%206l-.112%20.006a1%201%200%200%200%20-.669%201.619l3.501%204.375l-3.5%204.375a1%201%200%200%200%20.78%201.625h6a1%201%200%200%200%20.78%20-.375l4%20-5a1%201%200%200%200%200%20-1.25l-4%20-5a1%201%200%200%200%20-.78%20-.375h-6z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-check: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-check%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M5%2012l5%205l10%20-10%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-circle-arrow-right: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-circle-arrow-right%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%203a9%209%200%201%200%200%2018a9%209%200%200%200%200%20-18%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M16%2012l-4%20-4%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M16%2012h-8%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%2016l4%20-4%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-clock: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-clock%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M3%2012a9%209%200%201%200%2018%200a9%209%200%200%200%20-18%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%207v5l3%203%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-close: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-x%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M18%206l-12%2012%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M6%206l12%2012%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-copy: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-copy%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M7%207m0%202.667a2.667%202.667%200%200%201%202.667%20-2.667h8.666a2.667%202.667%200%200%201%202.667%202.667v8.666a2.667%202.667%200%200%201%20-2.667%202.667h-8.666a2.667%202.667%200%200%201%20-2.667%20-2.667z%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M4.012%2016.737a2.005%202.005%200%200%201%20-1.012%20-1.737v-10c0%20-1.1%20.9%20-2%202%20-2h10c.75%200%201.158%20.385%201.5%201%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-delete-item: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-trash-x%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M20%206a1%201%200%200%201%20.117%201.993l-.117%20.007h-.081l-.919%2011a3%203%200%200%201%20-2.824%202.995l-.176%20.005h-8c-1.598%200%20-2.904%20-1.249%20-2.992%20-2.75l-.005%20-.167l-.923%20-11.083h-.08a1%201%200%200%201%20-.117%20-1.993l.117%20-.007h16zm-9.489%205.14a1%201%200%200%200%20-1.218%201.567l1.292%201.293l-1.292%201.293l-.083%20.094a1%201%200%200%200%201.497%201.32l1.293%20-1.292l1.293%201.292l.094%20.083a1%201%200%200%200%201.32%20-1.497l-1.292%20-1.293l1.292%20-1.293l.083%20-.094a1%201%200%200%200%20-1.497%20-1.32l-1.293%201.292l-1.293%20-1.292l-.094%20-.083z%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M14%202a2%202%200%200%201%202%202a1%201%200%200%201%20-1.993%20.117l-.007%20-.117h-4l-.007%20.117a1%201%200%200%201%20-1.993%20-.117a2%202%200%200%201%201.85%20-1.995l.15%20-.005h4z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-dot: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-point%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%207a5%205%200%201%201%20-4.995%205.217l-.005%20-.217l.005%20-.217a5%205%200%200%201%204.995%20-4.783z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-dropdown: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-caret-down%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M18%209c.852%200%201.297%20.986%20.783%201.623l-.076%20.084l-6%206a1%201%200%200%201%20-1.32%20.083l-.094%20-.083l-6%20-6l-.083%20-.094l-.054%20-.077l-.054%20-.096l-.017%20-.036l-.027%20-.067l-.032%20-.108l-.01%20-.053l-.01%20-.06l-.004%20-.057v-.118l.005%20-.058l.009%20-.06l.01%20-.052l.032%20-.108l.027%20-.067l.07%20-.132l.065%20-.09l.073%20-.081l.094%20-.083l.077%20-.054l.096%20-.054l.036%20-.017l.067%20-.027l.108%20-.032l.053%20-.01l.06%20-.01l.057%20-.004l12.059%20-.002z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-error: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-alert-circle%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%202c5.523%200%2010%204.477%2010%2010a10%2010%200%200%201%20-19.995%20.324l-.005%20-.324l.004%20-.28c.148%20-5.393%204.566%20-9.72%209.996%20-9.72zm.01%2013l-.127%20.007a1%201%200%200%200%200%201.986l.117%20.007l.127%20-.007a1%201%200%200%200%200%20-1.986l-.117%20-.007zm-.01%20-8a1%201%200%200%200%20-.993%20.883l-.007%20.117v4l.007%20.117a1%201%200%200%200%201.986%200l.007%20-.117v-4l-.007%20-.117a1%201%200%200%200%20-.993%20-.883z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-help: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-help-circle%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%202c5.523%200%2010%204.477%2010%2010a10%2010%200%200%201%20-19.995%20.324l-.005%20-.324l.004%20-.28c.148%20-5.393%204.566%20-9.72%209.996%20-9.72zm0%2013a1%201%200%200%200%20-.993%20.883l-.007%20.117l.007%20.127a1%201%200%200%200%201.986%200l.007%20-.117l-.007%20-.127a1%201%200%200%200%20-.993%20-.883zm1.368%20-6.673a2.98%202.98%200%200%200%20-3.631%20.728a1%201%200%200%200%201.44%201.383l.171%20-.18a.98%20.98%200%200%201%201.11%20-.15a1%201%200%200%201%20-.34%201.886l-.232%20.012a1%201%200%200%200%20.111%201.994a3%203%200%200%200%201.371%20-5.673z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-info: url("data:image/svg+xml,%3C%3Fxml%20version%3D%221.0%22%20encoding%3D%22UTF-8%22%20standalone%3D%22no%22%3F%3E%0A%3C!DOCTYPE%20svg%20PUBLIC%20%22-%2F%2FW3C%2F%2FDTD%20SVG%201.1%2F%2FEN%22%20%22http%3A%2F%2Fwww.w3.org%2FGraphics%2FSVG%2F1.1%2FDTD%2Fsvg11.dtd%22%3E%0A%3Csvg%20width%3D%22100%25%22%20height%3D%22100%25%22%20viewBox%3D%220%200%2024%2024%22%20version%3D%221.1%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20xmlns%3Axlink%3D%22http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink%22%20xml%3Aspace%3D%22preserve%22%20xmlns%3Aserif%3D%22http%3A%2F%2Fwww.serif.com%2F%22%20style%3D%22fill-rule%3Aevenodd%3Bclip-rule%3Aevenodd%3Bstroke-linejoin%3Around%3Bstroke-miterlimit%3A2%3B%22%3E%0A%20%20%20%20%3Cpath%20d%3D%22M12%2C2C17.523%2C2%2022%2C6.477%2022%2C12L22%2C12.008C22%2C17.494%2017.486%2C22.008%2012%2C22.008C6.633%2C22.008%202.175%2C17.688%202.005%2C12.324L2%2C12L2.004%2C11.72C2.152%2C6.327%206.57%2C2%2012%2C2ZM13.5%2C16L13.5%2C11.484L13.49%2C11.484C13.49%2C10.932%2013.042%2C10.484%2012.49%2C10.484L9.99%2C10.484C9.438%2C10.484%208.99%2C10.932%208.99%2C11.484C8.99%2C12.036%209.438%2C12.484%209.99%2C12.484L11%2C12.484L11%2C16L9%2C16C8.448%2C16%208%2C16.448%208%2C17C8%2C17.552%208.448%2C18%209%2C18L15%2C18C15.552%2C18%2016%2C17.552%2016%2C17C16%2C16.448%2015.552%2C16%2015%2C16L13.5%2C16ZM12%2C5.5C11.172%2C5.5%2010.5%2C6.172%2010.5%2C7C10.5%2C7.828%2011.172%2C8.5%2012%2C8.5C12.828%2C8.5%2013.5%2C7.828%2013.5%2C7C13.5%2C6.172%2012.828%2C5.5%2012%2C5.5Z%22%2F%3E%0A%3C%2Fsvg%3E%0A");
  --ink-i-mobile-menu: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-menu-2%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%206l16%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%2012l16%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%2018l16%200%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-refresh: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-refresh%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M20%2011a8.1%208.1%200%200%200%20-15.5%20-2m-.5%20-4v4h4%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%2013a8.1%208.1%200%200%200%2015.5%202m.5%204v-4h-4%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-search: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-search%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M10%2010m-7%200a7%207%200%201%200%2014%200a7%207%200%201%200%20-14%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M21%2021l-6%20-6%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-settings: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-settings%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M14.647%204.081a.724%20.724%200%200%200%201.08%20.448c2.439%20-1.485%205.23%201.305%203.745%203.744a.724%20.724%200%200%200%20.447%201.08c2.775%20.673%202.775%204.62%200%205.294a.724%20.724%200%200%200%20-.448%201.08c1.485%202.439%20-1.305%205.23%20-3.744%203.745a.724%20.724%200%200%200%20-1.08%20.447c-.673%202.775%20-4.62%202.775%20-5.294%200a.724%20.724%200%200%200%20-1.08%20-.448c-2.439%201.485%20-5.23%20-1.305%20-3.745%20-3.744a.724%20.724%200%200%200%20-.447%20-1.08c-2.775%20-.673%20-2.775%20-4.62%200%20-5.294a.724%20.724%200%200%200%20.448%20-1.08c-1.485%20-2.439%201.305%20-5.23%203.744%20-3.745a.722%20.722%200%200%200%201.08%20-.447c.673%20-2.775%204.62%20-2.775%205.294%200zm-2.647%204.919a3%203%200%201%200%200%206a3%203%200%200%200%200%20-6z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-sort-ascending: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-sort-ascending%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%206l7%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%2012l7%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%2018l9%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M15%209l3%20-3l3%203%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M18%206l0%2012%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-sort-descending: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-sort-descending%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%206l9%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%2012l7%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M4%2018l7%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M15%2015l3%203l3%20-3%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M18%206l0%2012%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-success: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-circle-check%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M17%203.34a10%2010%200%201%201%20-14.995%208.984l-.005%20-.324l.005%20-.324a10%2010%200%200%201%2014.995%20-8.336zm-1.293%205.953a1%201%200%200%200%20-1.32%20-.083l-.094%20.083l-3.293%203.292l-1.293%20-1.292l-.094%20-.083a1%201%200%200%200%20-1.403%201.403l.083%20.094l2%202l.094%20.083a1%201%200%200%200%201.226%200l.094%20-.083l4%20-4l.083%20-.094a1%201%200%200%200%20-.083%20-1.32z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-unsort: var(--ink-i-close);
  --ink-i-user: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-user%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%202a5%205%200%201%201%20-5%205l.005%20-.217a5%205%200%200%201%204.995%20-4.783z%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M14%2014a5%205%200%200%201%205%205v1a2%202%200%200%201%20-2%202h-10a2%202%200%200%201%20-2%20-2v-1a5%205%200%200%201%205%20-5h4z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-vcs-commit: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22none%22%0A%20%20stroke%3D%22currentColor%22%0A%20%20stroke-width%3D%222%22%0A%20%20stroke-linecap%3D%22round%22%0A%20%20stroke-linejoin%3D%22round%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-outline%20icon-tabler-git-commit%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%2012m-3%200a3%203%200%201%200%206%200a3%203%200%201%200%20-6%200%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%203l0%206%22%20%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%2015l0%206%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-warning: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-alert-triangle%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M12%201.67c.955%200%201.845%20.467%202.39%201.247l.105%20.16l8.114%2013.548a2.914%202.914%200%200%201%20-2.307%204.363l-.195%20.008h-16.225a2.914%202.914%200%200%201%20-2.582%20-4.2l.099%20-.185l8.11%20-13.538a2.914%202.914%200%200%201%202.491%20-1.403zm.01%2013.33l-.127%20.007a1%201%200%200%200%200%201.986l.117%20.007l.127%20-.007a1%201%200%200%200%200%20-1.986l-.117%20-.007zm-.01%20-7a1%201%200%200%200%20-.993%20.883l-.007%20.117v4l.007%20.117a1%201%200%200%200%201.986%200l.007%20-.117v-4l-.007%20-.117a1%201%200%200%200%20-.993%20-.883z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-zoom-in: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-zoom-in%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M14%203.072a8%208%200%200%201%202.617%2011.424l4.944%204.943a1.5%201.5%200%200%201%20-2.008%202.225l-.114%20-.103l-4.943%20-4.944a8%208%200%200%201%20-12.49%20-6.332l-.006%20-.285l.005%20-.285a8%208%200%200%201%2011.995%20-6.643zm-4%202.928a1%201%200%200%200%20-.993%20.883l-.007%20.117v2h-2l-.117%20.007a1%201%200%200%200%200%201.986l.117%20.007h2v2l.007%20.117a1%201%200%200%200%201.986%200l.007%20-.117v-2h2l.117%20-.007a1%201%200%200%200%200%20-1.986l-.117%20-.007h-2v-2l-.007%20-.117a1%201%200%200%200%20-.993%20-.883z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-i-zoom-out: url("data:image/svg+xml,%3Csvg%0A%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%0A%20%20width%3D%2224%22%0A%20%20height%3D%2224%22%0A%20%20viewBox%3D%220%200%2024%2024%22%0A%20%20fill%3D%22currentColor%22%0A%20%20class%3D%22icon%20icon-tabler%20icons-tabler-filled%20icon-tabler-zoom-out%22%0A%3E%0A%20%20%3Cpath%20stroke%3D%22none%22%20d%3D%22M0%200h24v24H0z%22%20fill%3D%22none%22%2F%3E%0A%20%20%3Cpath%20d%3D%22M14%203.072a8%208%200%200%201%202.617%2011.424l4.944%204.943a1.5%201.5%200%200%201%20-2.008%202.225l-.114%20-.103l-4.943%20-4.944a8%208%200%200%201%20-12.49%20-6.332l-.006%20-.285l.005%20-.285a8%208%200%200%201%2011.995%20-6.643zm-1%205.928h-6l-.117%20.007a1%201%200%200%200%200%201.986l.117%20.007h6l.117%20-.007a1%201%200%200%200%200%20-1.986l-.117%20-.007z%22%20%2F%3E%0A%3C%2Fsvg%3E");
  --ink-anim-barber-pole-speed: 2s;
  --ink-g-border-container: var(--ink-u-border-thin) var(--ink-p-container-border-color) solid;
  --ink-g-border-header: var(--ink-u-border-thin) var(--ink-p-header-border-color) solid;
  --ink-g-border-input: var(--ink-u-border-thin) var(--ink-p-input-border-color) solid;
  --ink-g-border-side-panel: var(--ink-u-border-thin) var(--ink-p-side-panel-border-color) solid;
  --ink-g-shadow-std: 0px 2px 4px rgba(0, 0, 0, 0.1);
  --ink-g-shadow-l-dark: 0px 4px 6px rgba(0, 0, 0, 0.75);
  --ink-z-base: 1;
  --ink-z-deco: 20;
  --ink-z-event-overlay: 30;
  --ink-z-banner: 100;
  --ink-z-menu: 110;
  --ink-z-dialog: 120;
  --ink-z-page-overlay: 150;
  --ink-z-dnd-overloay: 200
}
@media (prefers-reduced-motion) {
  :root :root,
  [data-ink-color-scheme] :root {
    --ink-anim-barber-pole-speed: 4s
  }
}
.ink-c-alert,
:root {
  --ink-c-alert-close-icon: var(--ink-i-close);
  --ink-c-alert-standard-bg: var(--ink-p-grey-200);
  --ink-c-alert-standard-border-color: var(--ink-p-container-border-color);
  --ink-c-alert-standard-icon: var(--ink-i-info);
  --ink-c-alert-standard-fg: var(--ink-p-fg);
  --ink-c-alert-error-bg: var(--ink-p-accent-error-bg);
  --ink-c-alert-error-border-color: var(--ink-p-accent-error-border-color);
  --ink-c-alert-error-icon: var(--ink-i-error);
  --ink-c-alert-error-fg: var(--ink-p-accent-error-fg);
  --ink-c-alert-info-bg: var(--ink-p-accent-info-bg);
  --ink-c-alert-info-border-color: var(--ink-p-accent-info-border-color);
  --ink-c-alert-info-icon: var(--ink-i-info);
  --ink-c-alert-info-fg: var(--ink-p-accent-info-fg);
  --ink-c-alert-success-bg: var(--ink-p-accent-success-bg);
  --ink-c-alert-success-border-color: var(--ink-p-accent-success-border-color);
  --ink-c-alert-success-icon: var(--ink-i-success);
  --ink-c-alert-success-fg: var(--ink-p-accent-success-fg);
  --ink-c-alert-warning-bg: var(--ink-p-accent-warning-bg);
  --ink-c-alert-warning-border-color: var(--ink-p-accent-warning-border-color);
  --ink-c-alert-warning-icon: var(--ink-i-warning);
  --ink-c-alert-warning-fg: var(--ink-p-accent-warning-fg)
}
.ink-c-alert {
  display: grid;
  grid-template: "icon content close"/min-content auto min-content;
  margin: 0;
  width: 100%;
  --_ink-c-alert-bg: var(--ink-c-alert-standard-bg);
  --_ink-c-alert-border-color: var(--ink-c-alert-standard-border-color);
  --_ink-c-alert-fg: var(--ink-c-alert-standard-fg);
  --_ink-c-alert-icon: var(--ink-c-alert-standard-icon);
  background: var(--_ink-c-alert-bg);
  border-radius: var(--ink-u-border-radius-container);
  border: var(--ink-u-border-thin) var(--_ink-c-alert-border-color) solid;
  box-shadow: var(--ink-g-shadow-std);
  box-sizing: border-box;
  color: var(--_ink-c-alert-fg);
  font-size: var(--ink-u-font-std);
  padding: var(--ink-u-spacing-std)
}
.ink-c-alert:before {
  grid-area: icon;
  text-align: center;
  margin-right: var(--ink-u-spacing-s);
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--_ink-c-alert-icon);
  width: var(--ink-u-icon-l);
  height: var(--ink-u-icon-l)
}
.ink-c-alert[data-type=error] {
  --_ink-c-alert-bg: var(--ink-c-alert-error-bg);
  --_ink-c-alert-border-color: var(--ink-c-alert-error-border-color);
  --_ink-c-alert-icon: var(--ink-c-alert-error-icon);
  --_ink-c-alert-fg: var(--ink-c-alert-error-fg);
  --ink-p-link-fg: var(--ink-p-link-fg-on-light);
  --ink-p-link-hover-fg: var(--ink-p-link-hover-fg-on-light)
}
.ink-c-alert[data-type=info] {
  --_ink-c-alert-bg: var(--ink-c-alert-info-bg);
  --_ink-c-alert-border-color: var(--ink-c-alert-info-border-color);
  --_ink-c-alert-icon: var(--ink-c-alert-info-icon);
  --_ink-c-alert-fg: var(--ink-c-alert-info-fg);
  --ink-p-link-fg: var(--ink-p-link-fg-on-light);
  --ink-p-link-hover-fg: var(--ink-p-link-hover-fg-on-light)
}
.ink-c-alert[data-type=success] {
  --_ink-c-alert-bg: var(--ink-c-alert-success-bg);
  --_ink-c-alert-border-color: var(--ink-c-alert-success-border-color);
  --_ink-c-alert-icon: var(--ink-c-alert-success-icon);
  --_ink-c-alert-fg: var(--ink-c-alert-success-fg);
  --ink-p-link-fg: var(--ink-p-link-fg-on-light);
  --ink-p-link-hover-fg: var(--ink-p-link-hover-fg-on-light)
}
.ink-c-alert[data-type=warning] {
  --_ink-c-alert-bg: var(--ink-c-alert-warning-bg);
  --_ink-c-alert-border-color: var(--ink-c-alert-warning-border-color);
  --_ink-c-alert-icon: var(--ink-c-alert-warning-icon);
  --_ink-c-alert-fg: var(--ink-c-alert-warning-fg);
  --ink-p-link-fg: var(--ink-p-link-fg-on-light);
  --ink-p-link-hover-fg: var(--ink-p-link-hover-fg-on-light)
}
.ink-c-alert__actions {
  display: flex;
  margin-top: var(--ink-u-spacing-l);
  gap: var(--ink-u-spacing-std)
}
.ink-c-alert__body > :last-child {
  margin-bottom: 0;
  padding-bottom: 0
}
.ink-c-alert__content {
  grid-area: content;
  margin: 0;
  padding: 0;
  overflow: hidden
}
.ink-c-alert__close {
  grid-area: close;
  cursor: pointer;
  height: fit-content;
  margin: 0;
  line-height: 0;
  opacity: .6;
  padding: var(--ink-u-spacing-xs)
}
.ink-c-alert__close:before {
  background-color: currentColor;
  background-repeat: no-repeat;
  content: "";
  display: inline-block;
  mask-size: 100% 100%;
  mask-image: var(--ink-c-alert-close-icon);
  width: var(--ink-u-icon-std);
  height: var(--ink-u-icon-std)
}
.ink-c-alert__close:hover {
  opacity: 1
}
.ink-c-alert__heading {
  font-size: inherit;
  font-weight: 700;
  line-height: var(--ink-u-icon-l);
  margin: 0;
  padding: 0
}
.ink-c-button,
:root {
  --ink-c-button-border-radius: var(--ink-u-border-radius-s);
  --ink-c-button-busy-bg: rgba(0, 0, 0, 0.08);
  --ink-c-button-font-size: var(--ink-u-font-sm);
  --ink-c-button-padding-horiz: var(--ink-u-spacing-sm);
  --ink-c-button-padding-vert: var(--ink-u-spacing-s);
  --ink-c-button-shadow: var(--ink-g-shadow-std);
  --ink-c-button-keyboard-shortcut-font-size: var(--ink-u-font-s);
  --ink-c-button-accented-bg: var(--ink-p-accent-primary-bg) linear-gradient(to bottom, var(--ink-p-accent-secondary-bg), var(--ink-p-accent-primary-bg)) repeat-x;
  --ink-c-button-accented-active-bg: var(--ink-c-button-accented-bg) 0 -10px;
  --ink-c-button-accented-hover-bg: var(--if-dark, var(--ink-p-accent-primary-bg) linear-gradient(to bottom, var(--ink-p-accent-tertiary-bg), var(--ink-p-accent-secondary-bg) 35%, var(--ink-p-accent-primary-bg)) repeat-x 0 -5px) var(--if-light, var(--ink-c-button-primary-bg) 0 -10px);
  --ink-c-button-accented-fg: var(--ink-p-accent-primary-fg);
  --ink-c-button-bg: var(--if-dark, var(--ink-c-button-accented-bg)) var(--if-light, var(--ink-p-grey-200) linear-gradient(to bottom, white, white 25%, var(--ink-p-grey-200)) repeat-x);
  --ink-c-button-active-bg: var(--if-dark, var(--ink-c-button-accented-active-bg)) var(--if-light, var(--ink-c-button-bg) 0 -25px);
  --ink-c-button-hover-bg: var(--if-dark, var(--ink-c-button-accented-hover-bg)) var(--if-light, var(--ink-c-button-bg) 0 -8px);
  --ink-c-button-fg: var(--if-dark, var(--ink-c-button-accented-fg)) var(--if-light, var(--ink-p-surface-fg));
  --ink-c-button-border-color: rgba(0, 0, 0, 0.4);
  --ink-c-button-hover-border-color: rgba(0, 0, 0, 0.8);
  --ink-c-button-danger-bg: var(--ink-p-light__red-500) linear-gradient(to bottom, var(--ink-p-light__red-400), var(--ink-p-light__red-500)) repeat-x;
  --ink-c-button-danger-hover-bg: var(--if-dark, var(--ink-p-light__red-500) linear-gradient(to bottom, var(--ink-p-light__red-300), var(--ink-p-light__red-400) 35%, var(--ink-p-light__red-500)) repeat-x) var(--if-light, var(--ink-c-button-danger-bg) 0 -15px);
  --ink-c-button-danger-active-bg: var(--ink-c-button-danger-bg) 0 -25px;
  --ink-c-button-danger-fg: white;
  --ink-c-button-danger-border-color: var(--ink-c-button-border-color);
  --ink-c-button-danger-busy-bg: rgba(255, 255, 255, 0.08);
  --ink-c-button-disabled-bg: none;
  --ink-c-button-disabled-border-color: var(--if-dark, var(--ink-p-fg-on-dark)) var(--if-light, var(--ink-p-fg-on-light));
  --ink-c-button-disabled-fg: var(--if-dark, var(--ink-p-fg-on-dark)) var(--if-light, var(--ink-p-fg-on-light));
  --ink-c-button-disabled-busy-bg: var(--if-dark, rgba(255, 255, 255, 0.08)) var(--if-light, rgba(0, 0, 0, 0.08));
  --ink-c-button-primary-bg: var(--ink-c-button-accented-bg);
  --ink-c-button-primary-hover-bg: var(--ink-c-button-accented-hover-bg);
  --ink-c-button-primary-active-bg: var(--ink-c-button-accented-active-bg);
  --ink-c-button-primary-fg: var(--ink-c-button-accented-fg);
  --ink-c-button-primary-border-color: var(--ink-c-button-border-color);
  --ink-c-button-primary-busy-bg: rgba(255, 255, 255, 0.08)
}
.ink-c-button,
.ink-c-button:is(a:link,a:visited) {
  box-sizing: border-box;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  position: relative;
  font-weight: 400;
  line-height: normal;
  text-decoration: none;
  -webkit-user-select: none;
          user-select: none;
  --_ink-c-button-state-bg: var(--ink-c-button-bg);
  --_ink-c-button-state-active-bg: var(--ink-c-button-active-bg);
  --_ink-c-button-state-hover-bg: var(--ink-c-button-hover-bg);
  --_ink-c-button-state-border-color: var(--ink-c-button-border-color);
  --_ink-c-button-state-busy-bg: var(--ink-c-button-busy-bg);
  --_ink-c-button-state-fg: var(--ink-c-button-fg);
  background: var(--_ink-c-button-state-bg);
  border-width: var(--ink-u-border-thin);
  border-color: var(--_ink-c-button-state-border-color);
  border-style: solid;
  border-radius: var(--ink-c-button-border-radius);
  color: var(--_ink-c-button-state-fg);
  font-family: var(--ink-ff-sans-serif);
  transition: var(--ink-c-button-transition);
  gap: var(--ink-c-button-padding-horiz);
  padding: var(--ink-c-button-padding-vert) var(--ink-c-button-padding-horiz);
  vertical-align: top;
  cursor: pointer;
  font-size: var(--ink-c-button-font-size)
}
.ink-c-button > *,
.ink-c-button:is(a:link,a:visited) > * {
  cursor: inherit;
  color: inherit;
  font-family: inherit;
  font-size: inherit
}
.ink-c-button:is(:active,[aria-pressed=true],.js-active):is(a,button:enabled):not(.-is-disabled):not([aria-busy=true]),
.ink-c-button:is(a:link,a:visited):is(:active,[aria-pressed=true],.js-active):is(a,button:enabled):not(.-is-disabled):not([aria-busy=true]) {
  background: var(--_ink-c-button-state-active-bg);
  color: var(--_ink-c-button-state-fg);
  text-decoration: none;
  padding-top: calc(var(--ink-c-button-padding-vert) + .5px);
  padding-bottom: calc(var(--ink-c-button-padding-vert) - .5px);
  border-color: var(--ink-c-button-hover-border-color)
}
.ink-c-button:is(a:link,a:visited)[aria-busy=true],
.ink-c-button[aria-busy=true] {
  cursor: wait;
  overflow: hidden;
  color: var(--_ink-c-button-state-fg)
}
.ink-c-button:is(a:link,a:visited)[aria-busy=true]:after,
.ink-c-button[aria-busy=true]:after {
  content: "";
  display: block;
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  animation: linear ink-anim-barber-pole var(--ink-anim-barber-pole-speed) infinite reverse;
  background: linear-gradient(-45deg,var(--_ink-c-button-state-busy-bg) 25%,transparent 25%,transparent 50%,var(--_ink-c-button-state-busy-bg) 50%,var(--_ink-c-button-state-busy-bg) 75%,transparent 75%,transparent);
  background-size: 200% 200%
}
.ink-c-button:is([disabled],.-is-disabled),
.ink-c-button:is(a:link,a:visited):is([disabled],.-is-disabled) {
  cursor: default;
  --_ink-c-button-state-bg: var(--ink-c-button-disabled-bg);
  --_ink-c-button-state-fg: var(--ink-c-button-disabled-fg);
  --_ink-c-button-state-border-color: var(--ink-c-button-disabled-border-color);
  --_ink-c-button-state-busy-bg: var(--ink-c-button-disabled-busy-bg);
  color: var(--_ink-c-button-state-fg);
  opacity: .6
}
.ink-c-button:is(:focus,.js-focus),
.ink-c-button:is(a:link,a:visited):is(:focus,.js-focus) {
  color: var(--_ink-c-button-state-fg);
  outline-offset: 2px;
  z-index: 1
}
.ink-c-button:is(:hover,.js-hover):is(a,button:enabled):not(.-is-disabled):not([aria-busy=true]),
.ink-c-button:is(a:link,a:visited):is(:hover,.js-hover):is(a,button:enabled):not(.-is-disabled):not([aria-busy=true]) {
  background: var(--_ink-c-button-state-hover-bg);
  color: var(--_ink-c-button-state-fg);
  text-decoration: none
}
.ink-c-button:is([type=reset]),
.ink-c-button:is(a:link,a:visited):is([type=reset]) {
  --_ink-c-button-state-bg: var(--ink-c-button-danger-bg);
  --_ink-c-button-state-hover-bg: var(--ink-c-button-danger-hover-bg);
  --_ink-c-button-state-active-bg: var(--ink-c-button-danger-active-bg);
  --_ink-c-button-state-fg: var(--ink-c-button-danger-fg);
  --_ink-c-button-state-border-color: var(--ink-c-button-danger-border-color)
}
.ink-c-button:is([type=submit]),
.ink-c-button:is(a:link,a:visited):is([type=submit]) {
  --_ink-c-button-state-bg: var(--ink-c-button-primary-bg);
  --_ink-c-button-state-hover-bg: var(--ink-c-button-primary-hover-bg);
  --_ink-c-button-state-active-bg: var(--ink-c-button-primary-active-bg);
  --_ink-c-button-state-fg: var(--ink-c-button-primary-fg);
  --_ink-c-button-state-border-color: var(--ink-c-button-primary-border-color)
}
.ink-c-button.-is-danger,
.ink-c-button:is(a:link,a:visited).-is-danger {
  --_ink-c-button-state-bg: var(--ink-c-button-danger-bg);
  --_ink-c-button-state-hover-bg: var(--ink-c-button-danger-hover-bg);
  --_ink-c-button-state-active-bg: var(--ink-c-button-danger-active-bg);
  --_ink-c-button-state-fg: var(--ink-c-button-danger-fg);
  --_ink-c-button-state-border-color: var(--ink-c-button-danger-border-color)
}
.ink-c-button.-is-primary,
.ink-c-button:is(a:link,a:visited).-is-primary {
  --_ink-c-button-state-bg: var(--ink-c-button-primary-bg);
  --_ink-c-button-state-hover-bg: var(--ink-c-button-primary-hover-bg);
  --_ink-c-button-state-active-bg: var(--ink-c-button-primary-active-bg);
  --_ink-c-button-state-fg: var(--ink-c-button-primary-fg);
  --_ink-c-button-state-border-color: var(--ink-c-button-primary-border-color)
}
.ink-c-button__keyboard-shortcut {
  font-size: var(--ink-c-button-keyboard-shortcut-font-size)
}
.ink-c-button-group {
  display: inline-flex;
  margin: 0;
  padding: 0;
  font-size: 0
}
.ink-c-button-group .ink-c-button,
.ink-c-button-group .ink-c-button:is(a:link,a:visited) {
  margin: 0
}
.ink-c-button-group:not([aria-orientation]) .ink-c-button:is(a:link,a:visited):not(:first-child),
.ink-c-button-group:not([aria-orientation]) .ink-c-button:not(:first-child),
.ink-c-button-group[aria-orientation=horizontal] .ink-c-button:is(a:link,a:visited):not(:first-child),
.ink-c-button-group[aria-orientation=horizontal] .ink-c-button:not(:first-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  border-left: 0
}
.ink-c-button-group:not([aria-orientation]) .ink-c-button:is(a:link,a:visited):not(:last-child),
.ink-c-button-group:not([aria-orientation]) .ink-c-button:not(:last-child),
.ink-c-button-group[aria-orientation=horizontal] .ink-c-button:is(a:link,a:visited):not(:last-child),
.ink-c-button-group[aria-orientation=horizontal] .ink-c-button:not(:last-child) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  border-right-width: var(--ink-u-border-x-thin)
}
.ink-c-button-group[aria-orientation=vertical] {
  flex-direction: column
}
.ink-c-button-group[aria-orientation=vertical] .ink-c-button,
.ink-c-button-group[aria-orientation=vertical] .ink-c-button:is(a:link,a:visited) {
  width: 100%;
  justify-content: start
}
.ink-c-button-group[aria-orientation=vertical] .ink-c-button:is(a:link,a:visited):not(:first-child),
.ink-c-button-group[aria-orientation=vertical] .ink-c-button:not(:first-child) {
  border-top: 0;
  border-top-left-radius: 0;
  border-top-right-radius: 0
}
.ink-c-button-group[aria-orientation=vertical] .ink-c-button:is(a:link,a:visited):not(:last-child),
.ink-c-button-group[aria-orientation=vertical] .ink-c-button:not(:last-child) {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  border-bottom-width: var(--ink-u-border-x-thin)
}
.ink-c-dialog,
:root {
  --ink-c-dialog-title-bg: var(--ink-p-header-bg);
  --ink-c-dialog-title-border-color: var(--ink-p-header-border-color);
  --ink-c-dialog-width: 80%;
  --ink-c-dialog-height: 80%
}
.ink-c-dialog {
  border: 0;
  max-width: 100%;
  max-height: 100%;
  background: var(--ink-p-container-bg);
  border: var(--ink-u-border-thin) var(--ink-p-container-border-color-strong) solid;
  border-radius: var(--ink-u-border-radius-m);
  box-shadow: var(--ink-g-shadow-l-dark);
  color: var(--ink-p-container-fg);
  padding: 0;
  z-index: var(--ink-z-dialog)
}
.ink-c-dialog[open] {
  display: flex
}
.ink-c-dialog:not([data-size]),
.ink-c-dialog[data-size=fit] {
  width: fit-content;
  height: fit-content;
  min-width: 35vw;
  max-width: 60vw;
  max-height: 60vh
}
.ink-c-dialog[data-size=medium] {
  min-width: 60vw;
  max-width: 70vw;
  min-height: 60vh;
  max-height: 70vh
}
.ink-c-dialog[data-size=large] {
  min-width: 80vw;
  max-width: 80vw;
  min-height: 80vh;
  max-height: 80vh
}
.ink-c-dialog[data-size=max] {
  width: calc(100% - var(--ink-u-spacing-xxl));
  height: calc(100% - var(--ink-u-spacing-xxl))
}
.ink-c-dialog::backdrop {
  background: rgba(0,0,0,.85)
}
.ink-c-dialog__actions {
  display: flex;
  grid-area: actions;
  justify-content: space-between;
  height: min-content;
  padding: var(--ink-u-spacing-m);
  gap: var(--ink-u-spacing-m)
}
.ink-c-dialog__actions-primary,
.ink-c-dialog__actions-secondary {
  display: flex;
  gap: var(--ink-u-spacing-m)
}
.ink-c-dialog__body {
  grid-area: body;
  overflow: auto;
  padding: var(--ink-u-spacing-m)
}
.ink-c-dialog__inner {
  display: grid;
  flex-grow: 1;
  grid-template-areas: "title" "body" "actions";
  grid-template-rows: min-content 1fr min-content
}
.ink-c-dialog__suppress-label {
  display: flex;
  align-items: center;
  gap: var(--ink-u-spacing-xs)
}
.ink-c-dialog__title {
  grid-area: title;
  height: min-content;
  background: var(--ink-c-dialog-title-bg);
  border-bottom: var(--ink-u-border-thin) var(--ink-c-dialog-title-border-color) solid;
  border-radius: var(--ink-u-border-radius-m-inner) var(--ink-u-border-radius-m-inner) 0 0;
  font-weight: 700;
  padding: var(--ink-u-spacing-m)
}
.ink-c-keyboard-shortcut {
  display: inline-flex;
  gap: var(--ink-u-spacing-s)
}
.ink-c-keyboard-shortcut__key {
  background: var(--if-dark,rgba(255,255,255,.05)) var(--if-light,rgba(0,0,0,.05));
  border: var(--ink-u-border-thin) var(--if-dark,rgba(255,255,255,.1)) var(--if-light,rgba(0,0,0,.1)) solid;
  border-radius: var(--ink-u-border-radius-s);
  padding: var(--ink-u-spacing-xs) var(--ink-u-spacing-s);
  text-align: center
}
.ink-c-menu,
:root {
  --ink-c-menu-bg: var(--ink-p-container-bg);
  --ink-c-menu-border: var(--ink-g-border-container);
  --ink-c-menu-border-radius: var(--ink-u-border-radius-container);
  --ink-c-menu-shadow: var(--ink-g-shadow-std);
  --ink-c-menu-z-index: var(--ink-z-menu);
  --ink-c-menu-item-padding: var(--ink-u-spacing-m);
  --ink-c-menu-item-disabled-fg: var(--ink-p-fg-weak);
  --ink-c-menu-item-selected-bg: var(--ink-p-accent-primary-bg);
  --ink-c-menu-item-selected-fg: var(--ink-p-accent-primary-fg);
  --ink-c-menu-separator-border: var(--ink-u-border-thin) var(--if-dark, rgba(255, 255, 255, 0.1)) var(--if-light, rgba(0, 0, 0, 0.1)) solid
}
.ink-c-menu {
  display: none;
  line-height: 1;
  list-style: none;
  opacity: 0;
  overflow: hidden;
  text-align: left;
  -webkit-user-select: none;
          user-select: none;
  visibility: hidden;
  margin: 0;
  position: absolute;
  white-space: nowrap;
  background: var(--ink-c-menu-bg);
  border: var(--ink-c-menu-border);
  border-bottom-left-radius: var(--ink-c-menu-border-radius);
  border-bottom-right-radius: var(--ink-c-menu-border-radius);
  box-shadow: var(--ink-c-menu-shadow);
  color: var(--ink-p-fg);
  min-width: 15em;
  padding: var(--ink-c-menu-padding);
  z-index: var(--ink-c-menu-z-index);
  transition: opacity var(--ink-c-menu-transition-time) linear;
  outline: 0
}
.ink-c-menu.-has-icons .ink-c-menu__item-label:first-child {
  grid-column-start: 2
}
.ink-c-menu.-has-shortcuts .ink-c-menu__item-label:last-child {
  grid-column-end: -2
}
@supports (grid-template-columns:subgrid) {
  .ink-c-menu {
    display: grid;
    grid-template-columns: auto
  }
  .ink-c-menu .ink-c-menu__item {
    display: grid;
    grid-column: 1/-1;
    grid-template-columns: subgrid
  }
  .ink-c-menu .ink-c-menu__item-inner,
  .ink-c-menu .ink-c-menu__item-inner:link,
  .ink-c-menu .ink-c-menu__item-inner:visited {
    display: grid;
    grid-column: inherit;
    grid-template-columns: subgrid
  }
  .ink-c-menu .ink-c-menu__separator {
    grid-column: 1/-1
  }
  .ink-c-menu.-has-icons.-has-shortcuts {
    grid-template-columns: min-content 1fr min-content
  }
  .ink-c-menu.-has-icons:not(.-has-shortcuts) {
    grid-template-columns: max-content 1fr
  }
  .ink-c-menu.-has-shortcuts:not(.-has-icons) {
    grid-template-columns: 1fr min-content
  }
}
.ink-c-menu.-is-embedded {
  position: relative;
  border-radius: var(--ink-c-menu-border-radius)
}
.ink-c-menu.-is-open {
  opacity: 1;
  visibility: visible
}
.ink-c-menu:not(.-is-embedded):not(.-is-open) {
  display: none
}
.ink-c-menu__item {
  cursor: pointer;
  display: flex;
  margin: 0
}
.ink-c-menu__item[aria-disabled=true] {
  cursor: not-allowed;
  color: var(--ink-c-menu-item-disabled-fg)
}
.ink-c-menu__item[aria-selected=true] {
  background: var(--ink-c-menu-item-selected-bg);
  color: var(--ink-c-menu-item-selected-fg)
}
.ink-c-menu__item:focus {
  background: var(--ink-c-menu-item-selected-bg);
  outline: 0
}
.ink-c-menu__item.-is-header .ink-c-menu__item-label {
  font-weight: 700
}
.ink-c-menu__item.-is-header .ink-c-menu__item-inner,
.ink-c-menu__item.-is-header .ink-c-menu__item-inner:link,
.ink-c-menu__item.-is-header .ink-c-menu__item-inner:visited {
  cursor: initial
}
.ink-c-menu__item-icon {
  min-height: var(--ink-u-icon-m);
  min-width: var(--ink-u-icon-m)
}
.ink-c-menu__item-label {
  cursor: inherit;
  flex-grow: 1
}
.ink-c-menu__item-inner,
.ink-c-menu__item-inner:link,
.ink-c-menu__item-inner:visited {
  color: inherit;
  cursor: inherit;
  font-weight: 400;
  text-decoration: none;
  display: flex;
  flex: 1 1 auto;
  align-items: center;
  gap: var(--ink-u-spacing-m);
  padding: var(--ink-c-menu-item-padding)
}
.ink-c-menu__item-shortcut {
  justify-self: end
}
.ink-c-menu__separator {
  border-bottom: var(--ink-c-menu-separator-border)
}
.ink-c-menu-button {
  display: inline-block;
  position: relative
}
.ink-c-menu-button__dropdown-button {
  flex-direction: row-reverse
}
.ink-c-menu-label,
.ink-c-menu-label:link,
.ink-c-menu-label:visited {
  cursor: pointer;
  display: inline-flex;
  position: relative;
  text-decoration: none;
  color: var(--ink-p-fg)
}
.ink-c-menu-label:hover {
  text-decoration: none;
  color: var(--ink-p-fg)
}
.ink-c-menu-label[aria-disabled=true] {
  cursor: not-allowed;
  color: var(--ink-p-fg-weak)
}
.ink-c-menu-label[aria-expanded=true] {
  background: var(--ink-p-accent-secondary-bg);
  color: var(--ink-p-accent-secondary-fg)
}
.ink-c-menu-label[aria-expanded=true].-opens-up {
  border-radius: 0 0 var(--ink-u-border-radius-std) var(--ink-u-border-radius-std)
}
.ink-c-menu-label[aria-expanded=true]:not(.-opens-up) {
  border-radius: var(--ink-u-border-radius-std) var(--ink-u-border-radius-std) 0 0
}
.ink-c-menu-label__inner {
  display: inline-flex;
  align-items: center;
  gap: var(--ink-u-spacing-xs);
  padding: var(--ink-u-spacing-s)
}
.ink-c-spinner,
:root {
  --ink-c-spinner-size: 1em;
  --ink-c-spinner-image: url("data:image/svg+xml,%3Csvg%20width%3D%22100%25%22%20height%3D%22100%25%22%20viewBox%3D%220%200%2016%2016%22%20version%3D%221.1%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20style%3D%22stroke-linecap%3Around%3Bstroke-linejoin%3Around%3Bstroke-miterlimit%3A1.5%3B%22%3E%0A%20%3Cpath%20d%3D%22M11.514%2C14.035c-1.032%2C0.603%20-2.233%2C0.948%20-3.514%2C0.948c-3.854%2C0%20-6.983%2C-3.129%20-6.983%2C-6.983c0%2C-3.854%203.129%2C-6.983%206.983%2C-6.983%22%20style%3D%22fill%3Anone%3Bstroke%3A%23000%3Bstroke-width%3A2px%3B%22%2F%3E%0A%20%3CanimateTransform%0A%20%20%20attributeName%3D%22transform%22%0A%20%20%20type%3D%22rotate%22%0A%20%20%20from%3D%220%200%200%22%0A%20%20%20to%3D%22360%200%200%22%0A%20%20%20dur%3D%221.0s%22%0A%20%20%20repeatCount%3D%22indefinite%22%2F%3E%0A%3C%2Fsvg%3E%0A")
}
.ink-c-spinner {
  display: inline-block;
  align-self: center;
  justify-self: center;
  vertical-align: middle;
  background-color: currentColor;
  background-repeat: no-repeat;
  mask-image: var(--ink-c-spinner-image);
  width: var(--ink-c-spinner-size);
  height: var(--ink-c-spinner-size)
}
@keyframes ink-anim-barber-pole {
  100% {
    background-position: 100% 100%
  }
}
@keyframes ink-show-deprecated {
  0%,
  100% {
    outline-color: red
  }
  25% {
    outline-color: #00f
  }
  50% {
    outline-color: green
  }
  75% {
    outline-color: orange
  }
}
.ink-show-deprecations .ink-deprecated {
  animation: 6s infinite alternate ink-show-deprecated!important;
  outline: transparent double 3px;
  outline-offset: 3px
}
a:hover {
  color: var(--ink-p-link-hover-fg)
}
a:link {
  color: var(--ink-p-link-fg)
}
body {
  accent-color: var(--ink-p-accent-primary-bg);
  background: var(--ink-p-page-bg);
  color: var(--ink-p-fg);
  font-family: var(--ink-ff-default);
  font-size: var(--ink-u-font-std)
}
/*# sourceMappingURL=3rdparty.css.map */